@@ -20,7 +20,7 @@ if mode == "CMD"
 	$stdout.sync = true
 
 	def usage
-		puts "rast-register.rb $Revision: 1.14 $"
+		puts "rast-register.rb $Revision: 1.10.2.2 $"
 		puts " register to rast index files from tDiary's database."
 		puts " usage: ruby rast-regiser.rb [-p <tDiary directory>] [-c <tdiary.conf directory>]"
 		exit
@@ -58,7 +58,7 @@ end
 
 require 'rast'
 
-module TDiary
+module ::TDiary
 	#
 	# Database
 	#
@@ -120,9 +120,9 @@ module TDiary
 			}
 		end
 
-                def cache_path
-                        @conf.cache_path || "#{@conf.data_path}cache"
-                end
+		def cache_path
+			@conf.cache_path || "#{@conf.data_path}cache"
+		end
 
 		def db_path
 			@conf['rast.db_path'] || "#{cache_path}/rast".untaint
@@ -141,11 +141,11 @@ module TDiary
 			@date = diary.date
 			@diaries = {@date.strftime('%Y%m%d') => @diary} if @diaries.empty?
 			@plugin = ::TDiary::Plugin::new(
-							'conf' => @conf,
-							'cgi' => @cgi,
-							'cache_path' => cache_path,
-							'diaries' => @diaries
-							)
+				'conf' => @conf,
+				'cgi' => @cgi,
+				'cache_path' => cache_path,
+				'diaries' => @diaries
+				)
 			def @plugin.apply_plugin_alt( str, remove_tag = false )
 				apply_plugin( str, remove_tag )
 			end
@@ -220,12 +220,7 @@ module TDiary
 		def cookie_mail; ''; end
 
 		def convert(str)
-			case @encoding
-			when 'utf8'
-				NKF::nkf('-w -m0', str)
-			else
-				str
-			end
+			str
 		end
 	end
 
@@ -277,7 +272,7 @@ if mode == "CMD"
 		conf.hide_comment_form = true
 		conf.show_nyear = false
 		def conf.bot?; true; end
-		encoding = conf.options['rast.encoding'] || 'euc_jp'
+		encoding = 'utf8'
 		TDiary::RastRegisterMain.new(conf).execute(encoding)
 	rescue
 		print $!, "\n"
@@ -297,9 +292,9 @@ else
 		conf.hide_comment_form = true
 		conf.show_nyear = false
 		def conf.bot?; true; end
-	
+
 		diary = @diaries[@date.strftime('%Y%m%d')]
-		encoding = @options['rast.encoding'] || 'euc_jp'
+		encoding = 'utf8'
 		TDiary::RastDB.new(conf, encoding).transaction do |rast_db|
 			TDiary::RastRegister.new(rast_db, diary).execute(true)
 		end
@@ -318,7 +313,7 @@ else
 HTML
 			if @mode == 'saveconf'
 				if @cgi.valid?( 'rast_register_rebuild' )
-					encoding = @conf.options['rast.encoding'] || 'euc_jp'
+					encoding = 'utf8'
 					str << '<p>The following diaries were registered.</p>'
 					out = ''
 					TDiary::RastRegisterMain.new(@conf).execute(encoding, out)
