@@ -1,11 +1,11 @@
 #!/usr/bin/env ruby
-# rast-search.rb $Revision: 1.9 $
+# rast-search.rb $Revision: 1.6.2.2 $
 #
 # Copyright (C) 2005 Kazuhiko <kazuhiko@fdiary.net>
 # You can redistribute it and/or modify it under GPL2.
 #
-$KCODE= 'e'
-BEGIN { $defout.binmode }
+$KCODE= 'u'
+BEGIN { $stdout.binmode }
 
 if FileTest::symlink?( __FILE__ ) then
 	org_path = File::dirname( File::readlink( __FILE__ ) )
@@ -23,25 +23,25 @@ module TDiary
 	class TDiaryRast < ::TDiary::TDiaryBase
 		MAX_PAGES = 20
 		SORT_OPTIONS = [
-			["score", ""],
-			["date", "ս"],
+			["score", "スコア順"],
+			["date", "日付順"],
 		]
 		SORT_PROPERTIES = ["date"]
 		ORDER_OPTIONS = [
-			["asc", ""],
-			["desc", "߽"],
+			["asc", "昇順"],
+			["desc", "降順"],
 		]
 		NUM_OPTIONS = [10, 20, 30, 50, 100]
 
 		def initialize( cgi, rhtml, conf )
 			super
 			@db_path = conf.options['rast.db_path'] || "#{cache_path}/rast"
-			@encoding = conf.options['rast.encoding'] || 'euc_jp'
+			@encoding = 'utf8'
 			# conf.options['sp.selected'] = ''
 			parse_args
 			format_form
 			if @query.empty?
-				@msg = 'Ϥơָץܥ򲡤Ƥ'
+				@msg = '検索条件を入力して、「検索」ボタンを押してください'
 			else
 				search
 			end
@@ -87,7 +87,7 @@ module TDiary
 				@result = db.search(convert(@query), options)
 				@secs = Time.now - t
 			rescue
-				@msg = "顼: #{_($!.to_s)}</p>"
+				@msg = "エラー: #{_($!.to_s)}</p>"
 			ensure
 				db.close
 			end
@@ -118,7 +118,7 @@ module TDiary
 			end
 			buf = "<p class=\"infobar\">\n"
 			if current_page > 1
-				buf.concat(format_link("", @start - @num, @num))
+				buf.concat(format_link("前へ", @start - @num, @num))
 			end
 			if first_page > 1
 				buf.concat("... ")
@@ -134,7 +134,7 @@ module TDiary
 				buf.concat("... ")
 			end
 			if current_page < page_count
-				buf.concat(format_link("", @start + @num, @num))
+				buf.concat(format_link("次へ", @start + @num, @num))
 			end
 			buf.concat("</p>\n")
 			return buf
@@ -184,9 +184,9 @@ module TDiary
 		def format_form
 			@num_options = NUM_OPTIONS.collect { |n|
 				if n == @num
-					"<option value=\"#{n}\" selected>#{n}鷺</option>"
+					"<option value=\"#{n}\" selected>#{n}件ずつ</option>"
 				else
-					"<option value=\"#{n}\">#{n}鷺</option>"
+					"<option value=\"#{n}\">#{n}件ずつ</option>"
 				end
 			}.join("\n")
 			@sort_options = format_options(SORT_OPTIONS, @sort)
@@ -198,13 +198,7 @@ module TDiary
 		end
 
 		def convert(str)
-			case @encoding
-			when 'utf8'
-				require 'nkf'
-				NKF::nkf('-w -m0', str)
-			else
-				@conf.to_native(str)
-			end
+			@conf.to_native(str)
 		end
 	end
 end
