@@ -1,4 +1,5 @@
-# a.rb $Revision: 1.13 $
+# -*- coding: utf-8 -*-
+# a.rb
 #
 # Create anchor easily.
 #
@@ -38,8 +39,8 @@ require 'nkf'
 
 # Resources
 unless @resource_loaded then
-	def a_conf_label; "󥫡ưץ饰󼭽եԽ"; end
-	def a_conf_explain; "<p>1Ԥ1ĤΥ󥫡ˤʤޤեޥåȤϡ URL ̾ΤǤƹܤ϶Ƕڤޤ̾ΤϾάǽǤάϥ̾ΤȤƻȤޤ</p><p>㡧 bibo http://ponx.s5.xrea.com/bibo/ Linuxӥܡ</p>"; end
+	def a_conf_label; "アンカー自動生成プラグイン辞書ファイル編集"; end
+	def a_conf_explain; "<p>1行で1つのアンカーになります。フォーマットは、キー URL 名称です。各項目は空白で区切ります。名称は省略可能です。省略した場合はキーが名称として使われます。</p><p>例： bibo http://ponx.s5.xrea.com/bibo/ Linuxビボ〜ろく</p>"; end
 end
 def a_conf_cols; '70%'; end
 def a_conf_rows; 20; end
@@ -48,8 +49,8 @@ def a_conf_rows; 20; end
 A_REG_PIPE = /\|/
 A_REG_COLON = /\:/
 A_REG_URL = /:\/\//
-A_REG_CHARSET = /euc|sjis|jis/
-A_REG_CHARSET2 = /sjis|jis/
+A_REG_CHARSET = /utf8|euc|sjis|jis/
+A_REG_CHARSET2 = /euc|sjis|jis/
 A_REG_MY = /^\d{8}/
 
 if @options and @options["a.path"] 
@@ -199,3 +200,10 @@ add_conf_proc( 'a_conf', a_conf_label ) do
   a_conf_html(data)
 end
 
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
