@@ -1,11 +1,12 @@
-# amazon.rb $Revision: 1.64 $: Making link with image to Amazon using Amazon ECS.
+# amazon.rb: Making link with image to Amazon using Amazon ECS.
 #
 # see document: #{@lang}/amazon.rb
 #
 # Copyright (C) 2005-2007 TADA Tadashi <sho@spc.gr.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
-require 'open-uri'
+require 'net/http'
+require 'uri'
 require 'timeout'
 require 'rexml/document'
 
@@ -13,11 +14,45 @@ require 'rexml/document'
 @amazon_subscription_id = '1CVA98NEF1G753PFESR2'
 @amazon_require_version = '2007-01-17'
 
-def amazon_call_ecs( asin, id_type )
+@amazon_url_hash = {
+  'us' => 'http://www.amazon.com/exec/obidos/ASIN',
+  'jp' => 'http://www.amazon.co.jp/exec/obidos/ASIN',
+  'fr' => 'http://www.amazon.fr/exec/obidos/ASIN',
+  'uk' => 'http://www.amazon.co.uk/exec/obidos/ASIN',
+  'de' => 'http://www.amazon.de/exec/obidos/ASIN',
+  'ca' => 'http://www.amazon.ca/exec/obidos/ASIN',
+}
+
+@amazon_ecs_url_hash = {
+  'us' => 'http://honnomemo.appspot.com/rpaproxy/us/',
+  'jp' => 'http://honnomemo.appspot.com/rpaproxy/jp/',
+  'fr' => 'http://honnomemo.appspot.com/rpaproxy/fr/',
+  'uk' => 'http://honnomemo.appspot.com/rpaproxy/uk/',
+  'de' => 'http://honnomemo.appspot.com/rpaproxy/de/',
+  'ca' => 'http://honnomemo.appspot.com/rpaproxy/ca/',
+}
+
+def amazon_fetch( url, limit = 10 )
+	raise ArgumentError, 'HTTP redirect too deep' if limit == 0
+
+	px_host, px_port = (@conf['proxy'] || '').split( /:/ )
+	px_port = 80 if px_host and !px_port
+	res = Net::HTTP::Proxy( px_host, px_port ).get_response( URI::parse( url ) )
+	case res
+	when Net::HTTPSuccess
+		res.body
+	when Net::HTTPRedirection
+		amazon_fetch( res['location'].untaint, limit - 1 )
+	else
+		raise ArgumentError, res.error!
+	end
+end
+
+def amazon_call_ecs( asin, id_type, country = nil )
 	aid =  @conf['amazon.aid'] || ''
 	aid = 'cshs-22' if aid.empty?
 
-	url =  @amazon_ecs_url.dup
+	url = (@conf['amazon.endpoints'] || @amazon_ecs_url_hash)[country].dup
 	url << "?Service=AWSECommerceService"
 	url << "&SubscriptionId=#{@amazon_subscription_id}"
 	url << "&AssociateTag=#{aid}"
@@ -25,23 +60,27 @@ def amazon_call_ecs( asin, id_type )
 	url << "&ItemId=#{asin}"
 	url << "&IdType=#{id_type}"
 	url << "&SearchIndex=Books" if id_type == 'ISBN'
+	url << "&SearchIndex=All"   if id_type == 'EAN'
 	url << "&ResponseGroup=Medium"
 	url << "&Version=#{@amazon_require_version}"
 
-	proxy = @conf['proxy']
-	proxy = 'http://' + proxy if proxy
-	timeout( 10 ) do
-		open( url, :proxy => proxy ) {|f| f.read }
+	begin
+		timeout( 10 ) do
+			amazon_fetch( url )
+		end
+	rescue ArgumentError
 	end
 end
 
 def amazon_author( item )
 	begin
-		author = ''
-		item.elements.each( '*/Author' ) do |a|
-			author << a.text << '/'
+		author = []
+		%w(Author Creator Artist).each do |elem|
+			item.elements.each( "*/#{elem}" ) do |a|
+				author << a.text
+			end
 		end
-		@conf.to_native( author.chop, 'utf-8' )
+		@conf.to_native( author.uniq.join( '/' ), 'utf-8' )
 	rescue
 		'-'
 	end
@@ -59,9 +98,10 @@ def amazon_image( item )
 		when 2; 'Small'
 		else;   'Medium'
 		end
-		image[:src] = item.elements.to_a( "#{size}Image/URL" )[0].text
-		image[:height] = item.elements.to_a( "#{size}Image/Height" )[0].text
-		image[:width] = item.elements.to_a( "#{size}Image/Width" )[0].text
+		img = item.elements.to_a("#{size}Image")[0] || item.elements.to_a("ImageSets/ImageSet/#{size}Image")[0]
+		image[:src] = img.elements['URL'].text
+		image[:height] = img.elements['Height'].text
+		image[:width] = img.elements['Width'].text
 	rescue
 		base = @conf['amazon.default_image_base'] || 'http://www.tdiary.org/images/amazondefaults/'
 		case @conf['amazon.imgsize']
@@ -117,15 +157,17 @@ def amazon_detail_html( item )
 
 	url = amazon_url( item )
 	html = <<-HTML
-	<a href="#{url}">
+	<a class="amazon-detail" href="#{url}"><div class="amazon-detail">
 		<img class="amazon-detail left" src="#{h image[:src]}"
 		height="#{h image[:height]}" width="#{h image[:width]}"
-		alt="#{h title}" title="#{h title}">
-	</a>
-	<span class="amazon-title">#{h title}</span><br>
-	<span class="amazon-author">#{h author}</span><br>
-	<span class="amazon-label">#{h amazon_label( item )}</span><br>
-	<span class="amazon-price">#{h amazon_price( item )}</span><br style="clear: left">
+		alt="">
+		<div class="amazon-detail-desc">
+			<span class="amazon-title">#{h title}</span><br>
+			<span class="amazon-author">#{h author}</span><br>
+			<span class="amazon-label">#{h amazon_label( item )}</span><br>
+			<span class="amazon-price">#{h amazon_price( item )}</span>
+		</div><br style="clear: left">
+	</div></a>
 	HTML
 end
 
@@ -134,11 +176,11 @@ def amazon_to_html( item, with_image = true, label = nil, pos = 'amazon' )
 
 	author = amazon_author( item )
 	author = "(#{author})" unless author.empty?
-	
+
+	label ||= %Q|#{amazon_title( item )}#{author}|
+	alt = ''
 	if with_image and @conf['amazon.hidename'] || pos != 'amazon' then
-		label = ''
-	elsif not label
-		label = %Q|#{amazon_title( item )}#{author}|
+		label, alt = alt, label
 	end
 
 	if with_image
@@ -146,10 +188,10 @@ def amazon_to_html( item, with_image = true, label = nil, pos = 'amazon' )
 		unless image[:src] then
 			img = ''
 		else
+			size = @conf.iphone? ? '' : %Q|height="#{h image[:height]}" width="#{h image[:width]}"|
 			img = <<-HTML
 			<img class="#{h pos}" src="#{h image[:src]}"
-			height="#{h image[:height]}" width="#{h image[:width]}"
-			alt="#{h label}" title="#{h label}">
+			#{size} alt="#{h alt}">
 			HTML
 			img.gsub!( /\t/, '' )
 		end
@@ -159,7 +201,7 @@ def amazon_to_html( item, with_image = true, label = nil, pos = 'amazon' )
 	%Q|<a href="#{h url}">#{img}#{h label}</a>|
 end
 
-def amazon_secure_html( asin, with_image, label, pos = 'amazon' )
+def amazon_secure_html( asin, with_image, label, pos = 'amazon', country = nil )
 	with_image = false if @mode == 'categoryview'
 	label = asin unless label
 
@@ -167,8 +209,8 @@ def amazon_secure_html( asin, with_image, label, pos = 'amazon' )
 	if with_image and @conf['amazon.secure-cgi'] then
 		image = <<-HTML
 		<img class="#{h pos}"
-		src="#{h @conf['amazon.secure-cgi']}?asin=#{u asin};size=#{u @conf['amazon.imgsize']}"
-		alt="#{h label}" title="#{h label}">
+		src="#{h @conf['amazon.secure-cgi']}?asin=#{u asin};size=#{u @conf['amazon.imgsize']};country=#{u country}"
+		alt="">
 		HTML
 	end
 	image.gsub!( /\t/, '' )
@@ -177,7 +219,8 @@ def amazon_secure_html( asin, with_image, label, pos = 'amazon' )
 		label = ''
 	end
 
-	url =  "#{@amazon_url}/#{u asin}"
+	amazon_url = @amazon_url_hash[country]
+	url =  "#{amazon_url}/#{u asin}"
 	url << "/#{u @conf['amazon.aid']}" if @conf['amazon.aid'] and @conf['amazon.aid'].length > 0
 	url << "/ref=nosim/"
 	%Q|<a href="#{h url}">#{image}#{h label}</a>|
@@ -185,27 +228,29 @@ end
 
 def amazon_get( asin, with_image = true, label = nil, pos = 'amazon' )
 	asin = asin.to_s.strip # delete white spaces
+	asin.sub!(/\A([a-z]+):/, '')
+	country = $1 || @conf['amazon.default_country'] || @amazon_default_country
 	digit = asin.gsub( /[^\d]/, '' )
 	if digit.length == 13 then # ISBN-13
 		asin = digit
-		id_type = 'ISBN'
+		id_type = /^97[89]/ =~ digit ? 'ISBN' : 'EAN'
 	else
 		id_type = 'ASIN'
 	end
 
 	if @conf.secure then
-		amazon_secure_html( asin, with_image, label, pos )
+		amazon_secure_html( asin, with_image, label, pos, country )
 	else
 		begin
 			cache = "#{@cache_path}/amazon"
 			Dir::mkdir( cache ) unless File::directory?( cache )
 			begin
-				xml = File::read( "#{cache}/#{asin}.xml" )
+				xml = File::read( "#{cache}/#{country}#{asin}.xml" )
 			rescue Errno::ENOENT
-				xml =  amazon_call_ecs( asin, id_type )
-				File::open( "#{cache}/#{asin}.xml", 'wb' ) {|f| f.write( xml )}
+				xml =  amazon_call_ecs( asin, id_type, country )
+				File::open( "#{cache}/#{country}#{asin}.xml", 'wb' ) {|f| f.write( xml )}
 			end
-			doc = REXML::Document::new( xml ).root
+			doc = REXML::Document::new( REXML::Source::new( xml ) ).root
 			item = doc.elements.to_a( '*/Item' )[0]
 			if pos == 'detail' then
 				amazon_detail_html( item )
@@ -316,3 +361,10 @@ alias isbnImgLeft isbn_image_left
 alias isbnImgRight isbn_image_right
 alias isbnImg isbn_image
 alias amazon isbn_image
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
