@@ -1,4 +1,5 @@
-# append-css.rb: $Revision: 1.10 $
+# -*- coding: utf-8 -*-
+# append-css.rb
 #
 # Append CSS fragment via Preferences Page.
 #
@@ -19,14 +20,14 @@ end
 
 unless @resource_loaded then
 	def append_css_label
-		'CSSɲ'
+		'CSSの追加'
 	end
 
 	def append_css_desc
 		<<-HTML
-		<h3>CSS</h3>
-		<p>߻ꤷƤơޤˡ륷Ȥɲꤹ硢
-		ʲCSSҤϤƤ</p>
+		<h3>CSS断片</h3>
+		<p>現在指定してあるテーマに、スタイルシートを追加設定する場合、
+		以下にCSSの断片を入力してください。</p>
 		HTML
 	end
 end
@@ -42,3 +43,10 @@ add_conf_proc( 'append-css', append_css_label, 'theme' ) do
 	HTML
 end
 
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
