@@ -1,17 +1,18 @@
-# calendar3.rb $Revision: 1.41 $
+# -*- coding: utf-8 -*-
+# calendar3.rb
 #
-# calendar3: ɽƤΥɽޤ
-#  ѥ᥿: ʤ
+# calendar3: 現在表示している月のカレンダーを表示します．
+#  パラメタ: なし
 #
-# tdiary.confǻꤹ륪ץ:
+# tdiary.confで指定するオプション:
 #   @options['calendar3.show_todo']
-#     ѥ饰դΥ֥ȥȤǻꤷʸ󤬰פ
-#     Ĥɽξ硤Υѥ饰դƤ
-#     ͽȤpopup롥
+#     パラグラフのサブサイトルとここで指定した文字列が一致し
+#     かつその日の日記が非表示の場合，そのパラグラフの内容を
+#     予定としてpopupする．
 #
 #   @options['calendar3.show_popup']
-#     JavaScriptˤpopupɽ뤫ɤ
-#     άͤtrueʤΤǡɽʤΤfalseꤹ롥
+#     JavaScriptによるpopupを表示するかどうか．
+#     省略時の値はtrueなので，表示したくない場合のみfalseを設定する．
 #
 # Copyright (c) 2001,2002 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
@@ -133,7 +134,7 @@ def calendar3
 		result << %Q|<p class="message">@options['calendar3.erb'] is obsolete!<p>|
 	end
 
-	if @mode == 'latest'
+	if /^(latest|search)$/ =~ @mode
 		date = Time.now
 	else
 		date = @date
@@ -159,7 +160,7 @@ def calendar3
 				end
 			end
 			if todos.size != 0
-				result << %Q|<span class="calendar-todo"><a class="#{Calendar3::STYLE[kind]}" title="#{day}ͽ:&#13;&#10;#{todos.join "&#13;&#10;"}">#{day}</a></span>\n|
+				result << %Q|<span class="calendar-todo"><a class="#{Calendar3::STYLE[kind]}" title="#{day}日の予定:&#13;&#10;#{todos.join "&#13;&#10;"}">#{day}</a></span>\n|
 			else
 				result << %Q|<span class="calendar-normal"><a class="#{Calendar3::STYLE[kind]}">#{day}</a></span>\n|
 			end
@@ -382,4 +383,11 @@ if @calendar3_show_popup
 JAVASCRIPT
 	end
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
 # vim: set ts=3:
