@@ -1,9 +1,10 @@
-# category.rb $Revision: 1.45 $
+# category.rb
 #
 # Copyright (c) 2003 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
 #
 require 'pstore'
+autoload :Kconv, 'kconv'
 
 #
 # initialize
@@ -109,22 +110,24 @@ def category_list_sections
 	years = info.years
 	r = ''
 
-	@categorized.keys.sort.each do |c|
-		info.category = c
+	raise ::TDiary::NotFound if @categorized.empty? and bot?
+
+	@categorized.to_a.sort_by{|e| e[0].downcase}.each do |c, v|
+		info.category = [c]
 		if @category_icon[c]
 			img = %Q|<img class="category" src="#{h @category_icon_url}#{h @category_icon[c]}" alt="#{h c}">|
 		else
 			img = ''
 		end
 		r << <<HTML
-<div class="conf day">
+<div class="category day">
 	<h2><span class="title">#{img}#{info.make_anchor}</span></h2>
 	<div class="body">
 		<ul class="category">
 HTML
-		@categorized[c].keys.sort.each do |ymd|
+		v.to_a.sort_by{|e| e[0]}.each do |ymd, ary|
 			text = Time.local(ymd[0,4], ymd[4,2], ymd[6,2]).strftime(@conf.date_format)
-			@categorized[c][ymd].sort.each do |idx, title, excerpt|
+			ary.sort.each do |idx, title, excerpt|
 				r << %Q|\t\t\t<li><a href="#{h @index}#{anchor "#{ymd}#p#{'%02d' % idx}"}" title="#{h excerpt}">#{text}#p#{'%02d' % idx}</a> #{apply_plugin(title)}</li>\n|
 			end
 		end
@@ -143,13 +146,15 @@ def category_list_sections_mobile
 	years = info.years
 	r = ''
 
-	@categorized.keys.sort.each do |c|
-		info.category = c
+	raise ::TDiary::NotFound if @categorized.empty? and bot?
+
+	@categorized.to_a.sort_by{|e| e[0].downcase}.each do |c, v|
+		info.category = [c]
 		r << "<H2>#{info.make_anchor}</H2>"
 		r << "<UL>"
-		@categorized[c].keys.sort.each do |ymd|
+		v.to_a.sort_by{|e| e[0]}.each do |ymd, ary|
 			text = Time.local(ymd[0,4], ymd[4,2], ymd[6,2]).strftime(@conf.date_format)
-			@categorized[c][ymd].sort.each do |idx, title, excerpt|
+			ary.sort.each do |idx, title, excerpt|
 				r << %Q|<LI><A HREF="#{h @index}#{anchor "#{ymd}#p#{'%02d' % idx}"}">#{text}#p#{'%02d' % idx}</A> #{apply_plugin(title)}</LI>\n|
 			end
 		end
@@ -161,7 +166,7 @@ end
 def category_list
 	info = Category::Info.new(@cgi, @years, @conf)
 	@categories.map do |c|
-		info.category = c
+		info.category = [c]
 		info.make_anchor
 	end.join(" | \n")
 end
@@ -178,7 +183,7 @@ def category_dropdown_list(label = nil, multiple = nil)
 	end
 
 	options = ''
-	(['ALL'] + @categories).each do |c|
+	(['ALL'] + @categories.sort_by{|e| e.downcase}).each do |c|
 		options << %Q|\t\t<option value="#{h c}"#{" selected" if category.include?(c)}>#{h c}</option>\n|
 	end
 
@@ -217,6 +222,9 @@ class CGI
 	def initialize
 		@params = Hash.new([])
 	end
+	def referer; nil; end
+	def user_agent; nil; end
+	def request_method; 'GET'; end
 end
 
 #
@@ -229,7 +237,9 @@ class Info
 		@cgi = cgi
 		@years = years
 		@conf = conf
-		@category = args[:category] || @cgi.params['category']
+		@category = args[:category] || @cgi.params['category'].map {|c|
+			Kconv.isutf8(c) ? c : @conf.to_native(c, @conf.encoding_old)
+		}
 		@year = args[:year] || @cgi.params['year'][0]
 		@month = args[:month] || @cgi.params['month'][0]
 		@mode = :all
@@ -326,7 +336,7 @@ public
 				label = label.gsub(/\$1/, @year || '*')
 			end
 		else
-			label = @category.map.join(':')
+			label = @category.map.to_a.join(':')
 		end
 		%Q|<a href="#{h @conf.index}?#{h a}">#{h label}</a>|
 	end
@@ -479,7 +489,6 @@ class Cache
 	#
 	def recreate(years)
 		cgi = Category::CGI::new
-		def cgi.referer; nil; end
 
 		list = []
 		years.each do |y, ms|
@@ -541,7 +550,7 @@ class Cache
 private
 	def cache_file(category = nil)
 		if category
-			"#{@dir}/#{u category}".untaint
+			"#{@dir}/#{u( category ).gsub(/%20/,'+')}".untaint
 		else
 			"#{@dir}/category_list"
 		end
@@ -604,26 +613,38 @@ end # module Category
 #
 # display categories you use on update form
 #
-@conf['category.edit_support'] and add_edit_proc do |date|
-	ret = ''
-	unless @categories.size == 0 then
-		ret << %Q[
-		<script type="text/javascript">
-		<!--
-		function inj_c(val){
-			target = window.document.forms[0].body
-			target.focus();
-			target.value += val
+if @conf['category.edit_support'] then
+	add_header_proc do
+		%Q[\t<script type="text/javascript"><!--
+		function inj_c(str) {
+			var textarea = window.document.forms[0].body;
+			textarea.focus();
+			if (document.selection) { // IE, Opera
+				var range = document.selection.createRange();
+				range.text = str;
+			} else if (textarea.selectionStart != undefined) { // mozilla
+				var start = textarea.selectionStart;
+				var end = textarea.selectionEnd;
+				textarea.value = textarea.value.substring(0, start) + str + textarea.value.substring(end);
+				textarea.setSelectionRange(start + str.length, start + str.length);
+			 } else {
+				textarea.value += str;
+			 }
 		}
 		//-->
-		</script>
-		]
-		ret << '<div class="field title">'
-		ret << "#{@category_conf_label}:\n"
-		@categories.each do |c|
-			ret << %Q!| <a href="javascript:inj_c(&quot;[#{h c}]&quot;)">#{h c}</a>\n!
+		</script>\n]
+	end
+
+	add_edit_proc do |date|
+		ret = ''
+		unless @categories.size == 0 then
+			ret << '<div class="field title">'
+			ret << "#{@category_conf_label}:\n"
+			@categories.sort_by{|e| e.downcase}.each do |c|
+				ret << %Q!| <a href="javascript:inj_c(&quot;[#{h c}]&quot;)">#{h c}</a>\n!
+			end
+			ret << "|\n</div>\n<br>\n"
 		end
-		ret << "|\n</div>\n<br>\n"
 	end
 end
 
@@ -708,7 +729,7 @@ if @mode == 'conf' || @mode == 'saveconf'
 			].each do |name|
 				@conf[name] = @conf.to_native( @cgi.params[name][0] )
 			end
-			if ["month", "quearter", "half", "year", "all"].index(@cgi.params["category.period"][0])
+			if ["month", "quarter", "half", "year", "all"].index(@cgi.params["category.period"][0])
 				@conf["category.period"] = @cgi.params["category.period"][0]
 			end
 			@conf['category.edit_support'] = (@cgi.params['category.edit_support'][0] == 'true')
@@ -749,4 +770,10 @@ if @mode == 'categoryview'
 	@categorized = @category_cache.categorize(info.category, info.years)
 end
 
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
 # vim: ts=3
