@@ -1,11 +1,11 @@
 =begin
-= Υ󥯸⤦äȤץ饰((-$Id: disp_referrer.rb,v 1.69 2007/12/11 07:23:39 zunda Exp $-))
+= 本日のリンク元もうちょっとだけ強化プラグイン((-$Id: disp_referrer.rb,v 1.70 2008-03-02 09:01:45 kazuhiko Exp $-))
 
-== 
-ƥʤΥ󥯡󥸥θ̤̾Υ󥯸βˤ
-Ȥɽޤ󥸥θ̤ϡˤޤȤޤ
+== 概要
+アンテナからのリンク、サーチエンジンの検索結果を、通常のリンク元の下にま
+とめて表示します。サーチエンジンの検索結果は、検索語毎にまとめられます。
 
-ǿɽǤϡ̾Υ󥯸ʳΥ󥯸򱣤ޤ
+最新の日記の表示では、通常のリンク元以外のリンク元を隠します。
 
 == Acknowledgements
 This plugin uses
@@ -52,40 +52,25 @@ See ChangeLog for changes after this.
 - instance_eval for e[2] in the search engine list
 * Wed Aug  7, 2003 zunda <zunda at freeshell.org>
 - WWW browser configuration interface
-  - åιμ¤ˤ褦ˤޤWWW֥饦ִ
-    ꥹȤäˤϥꥹȤκǽɲäޤ
-  - secure=trueǤ¾Υ󥯸ꥹȤɽǤ褦ˤʤޤ
+  - キャッシュの更新をより確実にするようにしました。WWWブラウザから置換
+    リストを作った場合にはリストの最初に追加されます。
+  - secure=trueな日記でその他のリンク元リストが表示できるようになりました。
 - Regexp generation for Wiki sites
 * Wed Aug  6, 2003 zunda <zunda at freeshell.org>
 - WWW browser configuration interface
-  - ʥץȥ󥯸ִꥹȤθΨŪԽWWW֥饦
-    褦ˤʤޤsecure=trueǤϰεǽϻȤޤ
+  - 主なオプションとリンク元置換リストの効率的な編集がWWWブラウザからで
+    きるようになりました。secure=trueな日記では一部の機能は使えません。
 * Sat Aug  2, 2003 zunda <zunda at freeshell.org>
 - Second version
 - basic functions re-implemented
-  - ץ̿̾ʤޤޤפʥץäޤ
-    tdiary.confԽƤϡǤ򤷤ʤƤ
-  - Nora饤֥ȥåѤǹ®ޤ
-  - 󥸥ΥꥹȤץ饰ǻĤ褦ˤʤޤ&;ޤม
-    ʸ̤ФǤޤ
+  - オプションを命名しなおしました。また不要なオプションを消しました。
+    tdiary.confを編集していた方は、お手数ですが設定をしなおしてください。
+  - Noraライブラリとキャッシュの利用で高速化しました。
+  - 検索エンジンのリストをプラグインで持つようになりました。&や;を含む検
+    索文字列も期待通りに抽出できます。
 * Mon Feb 17, 2003 zunda <zunda at freeshell.org>
 - First version
 =end
-
-=begin
-== Υץ饰륯饹ȥ᥽å
-=== Array
-Array#values_at()̵硢ɲäޤ
-=end
-# 1.8 feature
-unless [].respond_to?( :values_at ) then
-	eval( <<-MODIFY_CLASS, TOPLEVEL_BINDING )
-		class Array
-			alias values_at indices
-		end
-	MODIFY_CLASS
-end
-
 # to be visible from inside classes
 Dispref2plugin = self
 Dispref2plugin_cache_path = @cache_path
@@ -97,8 +82,8 @@ Root_DispRef2URL = 'dispref2url' # root for DispRef2URLs
 
 =begin
 === Tdiary::Plugin::DispRef2DummyPStore
-PStoreƱ᥽åɤ󶡤ޤʤˤ⤷ޤdb[key]nil֤
-ȤդƤ
+PStoreと同じメソッドを提供しますがなにもしません。db[key]は全てnilを返す
+ことに注意してください。
 =end
 # dummy PStore
 class DispRef2DummyPStore
@@ -129,30 +114,30 @@ end
 
 =begin
 === Tdiary::Plugin::DispRef2CachePath
-DispRef2StoreΥѥδ򤷤ޤ
+DispRef2Storeのパスの管理をします。
 
 --- DispRef2CachePath::new( setup )
 
 --- DispRef2CachePath#cache( date )
-     ΤΥåΥѥ֤ޤ
+     その日の日記のためのキャッシュのパスを返します。
 
 --- DispRef2CachePath#caches
-      ¸ߤ뤽줾ΥåեΥѥ֤ޤ
+      現在存在するそれぞれのキャッシュファイルのパスの配列を返します。
 
 --- DispRef2CachePath#shrink
-      ǶȤƤʤå뤳Ȥǡ
-      å礭٤ޤޤ
+      最近使われていないキャッシュを削除することで、
+      キャッシュの大きさを設定値程度に抑えます。
 
 === Tdiary::Plugin::DispRef2PStore
-@secure=falseǤPStoreƱΥ᥽åɤ@secure=trueǤ
-⤷ʤ᥽åɤ󶡤ޤ
+@secure=falseな日記ではPStoreと同等のメソッドを、@secure=trueな日記では
+何もしないメソッドを提供します。
 
 --- DispRef2PSTore#transaction( read_only = false )
-     Ruby-1.7ʹߤξɤ߹Ѥ˳ȤǤޤRuby-1.6ξ
-     read_only = trueǤɤ߽Ѥ˳ޤ
+     Ruby-1.7以降の場合は読み込み専用に開くこともできます。Ruby-1.6の場
+     合はread_only = trueでも読み書き用に開きます。
 
 --- DispRef2PSTore#real?
-      ʪPSToreȤtrueǤʤfalse֤ޤ
+      本物のPSToreが使える時はtrue、そうでない時はfalseを返します。
 =end
 
 unless @conf and @conf.secure then
@@ -242,51 +227,51 @@ end
 
 =begin
 === Tdiary::Plugin::DispRef2String
-ʸɤѴURLHTMLǤμ갷˴ؤ᥽åɷǤ󥹥
-󥹤ϺޤUconv饤֥Nora饤֥꤬ФȤ̵
-̵ʤ˽ޤ
+文字コードの変換、URL、HTMLでの取り扱いに関するメソッド群です。インスタ
+ンスは作りません。UconvライブラリやNoraライブラリがあればそれを使い、無
+ければ無いなりに処理します。
 
 --- DispRef2String::nora?
-      NoraȤˤtrueǤʤȤˤfalse֤ޤ
+      Noraが使える時にはtrue、そうでないときにはfalseを返します。
 
 --- DispRef2String::normalize( str )
-      ³äsite:...Ȥʸäꤷơ
-      ɤ򵬳ʲޤ
+      続く空白を取り去ったりsite:...という文字列を消したりして、検索キー
+      ワードを規格化します。
 
 --- DispRef2String::parse_query( str )
-      URL˴ޤޤquery(key=value&...)Ϥ̤key򥭡
-      valueͤȤϥåȤ֤ޤͤΥ󥨥פ
-      ޤvalue̵ä϶ʸꤵޤ
+      URLに含まれるquery部(key=value&...)を解析し、結果をkeyをキー、
+      valueの配列を値としたハッシュとして返します。値のアンエスケープは
+      しません。valueが無かった場合は空文字列が設定されます。
 
 --- DispRef2String::separate_query( str )
-      URLqueryȸʬȤ֤ޤquery̵
-      nil֤ޤ
+      URLをquery部より前と後に分けて配列として返します。query部が無い場
+      合はnilを返します。
 
 --- DispRef2String::hostname( str )
-      URL˴ޤޤۥ̾뤤IPɥ쥹֤ޤۥ̾ߤ
-      ʤϡ((|str|))֤ޤ
+      URLに含まれるホスト名あるいはIPアドレスを返します。ホスト名がみつ
+      からない場合は、((|str|))を返します。
 
 --- DispRef2String::company_name( str, hash_list )
-      URLꡢgooglebiglobeȤä̾Τ((|hash_list|))key˴
-      ޤΤ֤ޤߤĤʤϡnil֤ޤ
+      URLより、googleやbiglobeといった名前のうち((|hash_list|))のkeyに含
+      まれるものを返します。みつからない場合は、nilを返します。
 
 --- DispRef2String::escapeHTML( str )
-      HTML˴ޤޤƤʤ褦˥פޤ
+      HTMLに含まれても安全なようにエスケープします。
 
 --- DispRef2String::unescape( str )
-      URL򥢥󥨥פޤ
+      URLをアンエスケープします。
 
 --- DispRef2String::bytes( size )
-      Хñ̤礭MB KB BŬڤñ̤Ѵޤ
+      バイト単位の大きさをMB KB Bの適切な単位に変換します。
 
 --- DispRef2String::comma( integer )
-      򥫥ޤ3夺Ĥʬޤ
+      数字をカンマで3桁ずつに分けます。
 
 --- DispRef2String::url_regexp( url )
-      ((|url|))ִꥹѤɽʸĤޤ
+      ((|url|))から置換リスト用の正規表現文字列をつくります。
 
 --- DispRef2String::url_match?( url, list )
-      ((|url|))((|list|))Τɤ줫˥ޥå뤫ɤĴ٤ޤ
+      ((|url|))が((|list|))のどれかにマッチするかどうか調べます。
 
 =end
 # string handling
@@ -294,7 +279,7 @@ class DispRef2String
 
 	# strips site:... portion (google), multiple spaces, and start/end spaces
 	def self::normalize( str )
-		str.sub( /\bsite:(\w+\.)*\w+\b/, '' ).gsub( /[\s\n]+/, ' ' ).strip
+		str.sub( /\bsite:(\w+\.)*\w+\b/u, '' ).gsub( /[　\s\n]+/u, ' ' ).strip
 	end
 
 	# parse_query parses the not unescaped query in a URL
@@ -429,41 +414,41 @@ end
 
 =begin
 === Tdiary::Plugin::DispRef2Setup
-ץ饰ưѥ᡼ꤷޤ
+プラグインの動作を決めるパラメータを設定します。
 
 --- DispRef2Setup::Last_parenthesis
-      ʸκǸ()Ȥ$1ꤵɽǤ
+      文字列の最後の()の中身が$1に設定される正規表現です。
 
 --- DispRef2Setup::First_bracket
-      ʸκǽ[]Ȥ$1ˡθʸ$2ꤵɽ
-      Ǥ
+      文字列の最初の[]の中身が$1に、その後の文字列が$2に設定される正規表
+      現です。
 
 --- DispRef2Setup::Defaults
-      ץΥǥեͤǤtDiaryΤ@optionsꤹˤϡ
-      Υϥåkeyˡdisp_referrer2.פĤkeyȤäƤ
-      ץξܺ٤ϥΥȤ򻲾ȤƤ
+      オプションのデフォルト値です。tDiary本体から@optionsで設定するには、
+      このハッシュのkeyの前に「disp_referrer2.」をつけたkeyを使ってくだ
+      さい。オプションの詳細はソースのコメントを参照してください。
 
 --- DispRef2Setup::new( conf, limit = 100, is_long = true )
-      ((|conf|))ˤtDiary@conf((|limit|))ˤϰܤɽ
-      󥯸((|is_long|))ϰʬɽξˤtrue򡢺ǿɽ
-      ξˤfalseꤷƤ
+      ((|conf|))にはtDiaryの@confを、((|limit|))には一項目あたりの表示リ
+      ンク元数を、((|is_long|))は一日分の表示の場合にはtrueを、最新の表
+      示の場合にはfalseを設定してください。
 
 --- DispRef2Setup#update!
-      tDiary@optionsˤ꼫Ȥ򹹿ޤ
+      tDiaryの@optionsにより自身を更新します。
 
 --- DispRef2Setup#is_long
 --- DispRef2Setup#referer_table
 --- DispRef2Setup#no_referer
 --- DispRef2Setup#secure
-      줾졢ʬɽɤtDiaryִơ֥롢tDiaryΥ
-      ꥹȡΥƥ֤ޤ
+      それぞれ、一日分の表示かどうか、tDiaryの置換テーブル、tDiaryのリン
+      ク元除外リスト、日記のセキュリティ設定を返します。
 
 --- DIspRef2Setup#to_native( str )
-      tDiaryθ꥽Ƥʸɤ᥽å
-      Ǥ
+      tDiaryの言語リソースで定義されている文字コードを正規化するメソッド
+      です。
 
 --- DispRef2Setup#[]
-      ꤵƤ֤ͤޤ
+      設定されている値を返します。
 =end
 # configuration of this plugin
 class DispRef2Setup < Hash
@@ -474,66 +459,66 @@ class DispRef2Setup < Hash
 	# default options
 	Defaults = {
 		'long.only_normal' => false,
-			# trueξ硢ʬɽǡ̾Υ󥯸ʳ򱣤ޤ
+			# trueの場合、一日分の表示で、通常のリンク元以外を隠します。
 		'short.only_normal' => true,
-			# trueξ硢ǿɽǡ̾Υ󥯸ʳ򱣤ޤ
-			# falseξϡץ饰̵ʤɽˤʤޤ
+			# trueの場合、最新の表示で、通常のリンク元以外を隠します。
+			# falseの場合は、プラグインの無い場合と全くおなじ表示になります。
 		'antenna.url' => '(\/a\/|(?!.*\/diary\/)antenna[\/\.]|\/tama\/|\Ahttp:\/\/www\.tdiary\.net\/?(i\/)?(\?|$)|links?|\Ahttp:\/\/kitaj\.no-ip\.com\/iraira\/|\Ahttp:\/\/i-know\.jp\/|\Ahttp:\/\/(www\.)?bloglines\.com\/(myblogs|public)_display|\Ahttp:\/\/del\.icio\.us\/\w+|\Ahttp:\/\/reader\.livedoor\.com\/reader\/)',
-			# ƥʤURL˰פɽʸǤ
-		'antenna.title' => '(ƥ|links?|Ƥ|antenna|entry|entries|󥯽|RSS|֥åޡ)',
-			# ƥʤִʸ˰פɽʸǤ
+			# アンテナのURLに一致する正規表現の文字列です。
+		'antenna.title' => '(アンテナ|links?|あんてな|antenna|entry|entries|リンク集|RSS|ブックマーク)',
+			# アンテナの置換後の文字列に一致する正規表現の文字列です。
 		'normal.label' => Dispref2plugin.referer_today,
-			# ̾Υ󥯸ΥȥǤǥեȤǤϡΥ󥯸פǤ
+			# 通常のリンク元のタイトルです。デフォルトでは、「本日のリンク元」です。
 		'antenna.label' => Disp_referrer2_antenna_label,
-			# ƥʤΥ󥯸ΥȥǤ
+			# アンテナのリンク元のタイトルです。
 		'unknown.label' => Disp_referrer2_unknown_label,
-			# ¾Υ󥯸ΥȥǤ
+			# その他のリンク元のタイトルです。
 		'unknown.hide' => false,
-			# trueξϥ󥯸ִꥹȤˤʤURLɽޤ
+			# trueの場合はリンク元置換リストにないURLは表示しません
 		'search.label' => Disp_referrer2_search_label,
-			# 󥸥󤫤Υ󥯸ΥȥǤ
+			# 検索エンジンからのリンク元のタイトルです。
 		'unknown.divide' => true,
-			# trueξ硢ִꥹȤ̵URL̾Υ󥯸ʬɽޤ
-			# falseξ硢ִꥹȤ̵URL̾Υ󥯸Ⱥɽޤ
+			# trueの場合、置換リストに無いURLを通常のリンク元と分けて表示します。
+			# falseの場合、置換リストに無いURLを通常のリンク元と混ぜて表示します。
 		'normal.group' => true,
-			# trueξ硢ִʸ̾Υ󥯸򥰥롼פޤ
-			# falseξ硢URL̤Υ󥯸Ȥɽޤ
+			# trueの場合、置換後の文字列で通常のリンク元をグループします。
+			# falseの場合、URL毎に別のリンク元として表示します。
 		'normal.categorize' => true,
-			# trueξ硢ִʸκǽ[]ʸǥƥ꡼ʬޤ
+			# trueの場合、置換後の文字列の最初の[]の文字列でカテゴリー分けします。
 		'normal.ignore_parenthesis' => true,
-			# trueξ硢롼פݤִʸκǸ()̵뤷ޤ
+			# trueの場合、グループする際に置換後の文字列の最後の()を無視します。
 		'antenna.group' => true,
-			# trueξ硢ִʸ̾Υ󥯸򥰥롼פޤ
-			# falseξ硢URL̤Υ󥯸Ȥɽޤ
+			# trueの場合、置換後の文字列で通常のリンク元をグループします。
+			# falseの場合、URL毎に別のリンク元として表示します。
 		'antenna.ignore_parenthesis' => true,
-			# trueξ硢롼פݤִʸκǸ()̵뤷ޤ
+			# trueの場合、グループする際に置換後の文字列の最後の()を無視します。
 		'search.expand' => false,
-			# trueξ硢ɤȤȤ˸󥸥̾ɽޤ
-			# falseξ硢Τߤɽޤ
+			# trueの場合、検索キーワードとともに検索エンジン名を表示します。
+			# falseの場合、回数のみを表示します。
 		'search.unknown_keyword' => Disp_referrer2_search_unknown_keyword,
-			# ɤ狼ʤ󥸥󤫤Υ󥯤˻ȤʸǤ
+			# キーワードがわからない検索エンジンからのリンクに使う文字列です。
 		'search_engines' => DispReferrer2_Engines,
-			# 󥸥ΥϥåǤ
+			# 検索エンジンのハッシュです。
 		'cache_label' => Disp_referrer2_cache_label,
-			# 󥸥ΥåURLɽʸǤ
+			# 検索エンジンのキャッシュのURLを表示する文字列です。
 		'cache_path' => "#{Dispref2plugin_cache_path}/disp_referrer2.cache",
-			# Υץ饰ǻȤåեΥѥǤ
-			# ΥץϸߤϻȤƤޤ
+			# このプラグインで使うキャッシュファイルのパスです。
+			# このオプションは現在は使われていません。
 		'cache_dir' => "#{Dispref2plugin_cache_path}/disp_referrer2.d",
-			# Υץ饰ǻȤåեΥǥ쥯ȥǤ
+			# このプラグインで使うキャッシュファイルのディレクトリです。
 		'cache_max_size' => 10485760,	# 10MB
-			# åι̤(Х)Ǥۤޤ
-			# 0̤ʤ¤ޤ
+			# キャッシュの合計量の制限(バイト)です。時々越えます。
+			# 0未満なら制限しません。
 		'no_cache' => false,
-			# trueξ硢@secure=falseǤ⥭åȤޤ
+			# trueの場合、@secure=falseな日記でもキャッシュを使いません。
 		'normal-unknown.title' => '\Ahttps?:\/\/',
-			# ִ줿֤¾פΥ󥯸Υȥ롢뤤ִƤ
-			# 󥯸Υȥ˥ޥåޤ
+			# 置換された「その他」のリンク元のタイトル、あるいは置換されていな
+			# いリンク元のタイトルにマッチします。
 		'configure.use_link' => true,
-			# 󥯸ִꥹȤԽ̤ǡ󥯸ؤΥ󥯤ޤ
+			# リンク元置換リストの編集画面で、リンク元へのリンクを作ります。
 		'reflist.ignore_urls' => '',
-			# ִꥹȤΥꥹȥåפκݤ̵뤹URLɽʸ
-			# \nڤ¤٤ޤ
+			# 置換リストのリストアップの際に無視するURLの正規表現の文字列
+			# \n区切で並べます
 	}
 
 	attr_reader :is_long, :referer_table, :no_referer, :secure, :years, :conf
@@ -626,28 +611,28 @@ end
 === Tdiary::Plugin::DispRef2URL
 
 --- DispRef2URL::new( unescaped_url, setup = nil )
-      ǤURL򸵤ˤƥ󥹥󥹤ޤ((|setup|))nilǤϤʤ
-      ˤϡparse( ((|setup|)) ) ⤷ޤ
+      素のURLを元にしてインスタンスを生成します。((|setup|))がnilではない
+      場合には、parse( ((|setup|)) ) もします。
 
 --- DispRef2URL#restore( db )
-      å夫鼫ʬURLбФޤ((|db|))
-      DispRef2PStoreΥ󥹥󥹤Ǥå夵Ƥʤä
-      ˤnil֤ޤ
+      キャッシュから自分のURLに対応する情報を取り出します。((|db|))は
+      DispRef2PStoreのインスタンスです。キャッシュされていなかった場合
+      にはnilを返します。
 
 --- DispRef2URL#parse( setup )
-      DispRef2SetupΥ󥹥((|setup|))ˤäơʬϤޤ
+      DispRef2Setupのインスタンス((|setup|))にしたがって、自分を解析します。
 
 --- DispRef2URL::Cached_options
-      DispRef2Setupꤵ륪ץΤå˱ƶͿ
-      Τ֤ޤ
+      DispRef2Setupで設定されるオプションのうち、キャッシュに影響を与え
+      るものの配列を返します。
 
 --- DispRef2URL#store( db )
-      å˼ʬϿޤ((|db|))DispRef2PStoreΥ󥹥
-      󥹤ǤϿϼʬ򡢤Ǥʤˤnil֤
-      ޤ
+      キャッシュに自分を記録します。((|db|))はDispRef2PStoreのインスタ
+      ンスです。記録に成功した場合は自分を、そうでない場合にはnilを返し
+      ます。
 
 --- DispRef2URL#==( other )
-      Ϸ̤˿֤ޤ
+      解析結果が等しい場合に真を返します。
 
 --- DispRef2URL#url
 --- DispRef2URL#category
@@ -656,10 +641,10 @@ end
 --- DispRef2URL#title_ignored
 --- DispRef2URL#title_group
 --- DispRef2URL#key
-      줾졢URLƥ꡼ƥ꡼̾(桼ꤷʤnil)
-      ȥ롢롼ײ̵뤵줿ȥ(̵nil)
-      ײΥȥ롢롼ײݤΥ֤ޤparse
-      뤤restoreʤꤵޤ
+      それぞれ、URL、カテゴリー、カテゴリー名(ユーザーが設定しなければnil)、
+      タイトル、グループ化した時に無視されたタイトル(無ければnil)、グル
+      ープ化した後のタイトル、グループ化する際のキーを返します。parseあ
+      るいはrestoreしないと設定されません。
 
 =end
 # handling of a URL
@@ -827,13 +812,13 @@ class DispRef2URL
 			title = setup.to_native( DispRef2String::unescape( @url ) )
 			setup.referer_table.each do |url, name|
 				unless /\$\d/ =~ name then
-					if title.gsub!( /#{url}/i, name ) then
+					if title.gsub!( /#{url}/iu, name ) then
 						matched = true
 						break
 					end
 				else
 					name.untaint unless setup.secure
-					if title.gsub!( /#{url}/i ) { eval name } then
+					if title.gsub!( /#{url}/iu ) { eval name } then
 						matched = true
 						break
 					end
@@ -900,21 +885,21 @@ end
 =begin
 === Tdiary::Plugin::DispRef2Refs
 --- DispRef2Refs::new( diary, setup )
-      ((|diary|))Υ󥯸DispRef2SetupΥ󥹥((|setup|))
-      ˤäƲϤޤ
+      日記((|diary|))のリンク元を、DispRef2Setupのインスタンス((|setup|))
+      にしたがって解析します。
 
 --- DispRef2Refs#special_categories
-      ִʸκǽ[]Ǥäƥ̾٥뤳Ȥˤ
-      ƥ桼ˤä줿ƥ꡼֤ޤ
+      置換文字列の最初に[]でかこったカテゴリ名ラベルを挿入することによっ
+      てユーザーによって定義されたカテゴリーの配列を返します。
 
 --- DispRef2Refs#urls( category = nil )
-      󥯸Τƥ꡼((|category|))˰פΤ
-      DispRef2Cache#urlsƱͤΥեޥåȤ֤ޤ((|category|))
-      nilξƤURLξ֤ޤ
+      リンク元のうち、カテゴリーが((|category|))に一致するものを、
+      DispRef2Cache#urlsと同様のフォーマットで返します。((|category|))
+      がnilの場合は全てのURLの情報を返します。
 
 --- DispRef2Refs#to_long_html
 --- DispRef2Refs#to_short_html
-      󥯸ΥꥹȤHTMLҤˤޤ
+      リンク元のリストをHTML断片にします。
 
 =end
 class DispRef2Refs
@@ -1091,24 +1076,24 @@ end
 
 =begin
 === Tdiary::Plugin::DispRef2Cache
-åδ򤹤륯饹Ǥ
+キャッシュの管理をするクラスです。
 
 --- DispRef2Cache.new( setup )
-      󥯸ΥåDispRef2SetupΥ󥹥((|setup|))ˤ
-      äƴޤ
+      リンク元のキャッシュを、DispRef2Setupのインスタンス((|setup|))にした
+      がって管理します。
 
 --- DispRef2Cache#urls( category = nil, nmonth = 2 )
-      å夵ƤURLξΤƥ꡼((|category|))
-      פΤURL򥭡ͤȤϥåȤ֤
-      ޤ((|category|))nilξƤURLξ֤ޤ
-      ((|nmonth|))nilǤϤʤϡǶNMONTHʬΥå
-      ޤ
-      * ƥ꡼
-      * ƥ꡼Υ٥(뤤nil)
-      * ִʸ
-      * 롼פݤ̵뤵줿ʸ
-      * 롼Τʸ
-      * 롼פݤΥ
+      キャッシュされているURLの情報のうち、カテゴリーが((|category|))に
+      一致するものを、URLをキー、下記の配列を値としたハッシュとして返し
+      ます。((|category|))がnilの場合は全てのURLの情報を返します。
+      ((|nmonth|))がnilではない場合は、最近NMONTH分のキャッシュだけから
+      検索します。
+      * カテゴリー
+      * カテゴリーのラベル(あるいはnil)
+      * 置換後の文字列
+      * グループする際に無視された文字列
+      * グループ全体の文字列
+      * グループする際のキー
 
 =end
 # cache management
@@ -1144,31 +1129,31 @@ end
 
 =begin
 === TDiary::Plugin::DispRef2SetupIF
-Υץ饰ΤHTMLCGIꥯȤޤ
+このプラグインの設定のためのHTMLを生成し、CGIリクエストを受け取ります。
 
 --- DispRef2SetupIF::new( cgi, setup, conf, mode )
-      CGIΥ󥹥((|cgi|))DispRef2SetupΥ󥹥((|setup|))
-      ꡢΤΥ󥹥󥹤ޤTDiary::Pluginꡢ
-      @conf@mode˻ꤷƤ
+      CGIのインスタンス((|cgi|))とDispRef2Setupのインスタンス((|setup|))
+      より、設定のためのインスタンスを生成します。TDiary::Pluginより、
+      @confと@modeも引数に指定してください。
 
 --- DispRef2SetupIF#show_html
-      ιɬפʤ饭åι򤷤ƤHTMLɽޤ
+      設定の更新と必要ならキャッシュの更新をしてからHTMLを表示します。
 
 --- DispRef2SetupIF#show_description
-      Υץ饰HTMLǤǤꤹܤ٤ޤ
+      このプラグインのHTML版の説明です。設定する項目も選べます。
 
 --- DispRef2SetupIF#show_options
-      Υץ饰ΥץꤹHTMLҤ֤ޤ
+      このプラグインのオプションを設定するHTML断片を返します。
 
 --- DispRef2SetupIF#show_unknown_list
-      󥯸ִꥹȤԽΤHTMLҤ֤ޤ
+      リンク元置換リストの編集のためのHTML断片を返します。
 
 --- DispRef2SetupIF#update_options
-      cgiϤ˱ơΥץ饰Υץ򹹿ޤ
-      @setup⹹ޤ
+      cgiからの入力に応じて、このプラグインのオプションを更新します。
+      @setupも更新します。
 
 --- DispRef2SetupIF#update_tables
-      cgiϤ˱ơ󥯸ִꥹȤ򹹿ޤ
+      cgiからの入力に応じて、リンク元置換リストを更新します。
 =end
 # WWW Setup interface
 class DispRef2SetupIF
@@ -1393,16 +1378,16 @@ end
 
 =begin
 === TDiary::Plugin::DispRef2Latest
-å夬̵ˡץ饰Υ󥯸뤿Υ饹
-Ǥ
+キャッシュが無い場合に、設定プラグインで不明のリンク元を得るためのクラス
+です。
 
 --- DispRef2Latest::new( cgi, skeltonfile, conf, setup )
-      TDiary::TDiaryLatestΰ˲äơDispRef2SetupΥ󥹥
-      ((|setup|))ˤȤޤ
+      TDiary::TDiaryLatestの引数に加えて、DispRef2Setupのインスタンス
+      ((|setup|))を引数にとります。
 
 --- DispRef2Latest::unknown_urls
-      ǿΥ󥯸ΤִǤʤäΤURL֤
-      ޤִǤʤäURL̵ˤ϶֤ޤ
+      最新の日記のリンク元のうち、置換できなかったもののURLの配列を返し
+      ます。置換できなかったURLが無い場合には空の配列を返します。
 
 =end
 class DispRef2Latest < TDiary::TDiaryLatest
@@ -1437,10 +1422,10 @@ end
 =begin
 === Tdiary::Plugin
 --- Tdiary::Plugin#configure_disp_referrer2
-      Υץ饰Τ˻Ȥ᥽åɤǤadd_conf_proc
-      ޤ
+      このプラグインの設定のために使われるメソッドです。add_conf_procさ
+      れます。
 
-ʲϡΥץ饰ǥС饤ɤtDiaryΥ᥽åɤǤ
+以下は、このプラグインでオーバーライドされるtDiaryのメソッドです。
 --- Tdiary::Plugin#referer_of_today_long( diary, limit = 100 )
 --- Tdiary::Plugin#referer_of_today_short( diary, limit = 10 )
 =end
@@ -1484,3 +1469,10 @@ then
 else
 	DispRef2Latest_cache = nil
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
