@@ -1,13 +1,14 @@
-# dropdown_calendar.rb $Revision: 1.5 $
+# -*- coding: utf-8 -*-
+# dropdown_calendar.rb
 #
-# calendar: ɥåץꥹȤ֤ץ饰
-#   ѥ᥿: ʤ
+# calendar: カレンダーをドロップダウンリストに置き換えるプラグイン
+#   パラメタ: なし
 #
 # 	Copyright (C) 2003 TADA Tadashi
 #	You can redistribute it and/or modify it under GPL2.
 #
 
-@dropdown_calendar_label = '' unless @resource_loaded
+@dropdown_calendar_label = '過去の日記' unless @resource_loaded
 
 def calendar
 	result = %Q[<form method="get" action="#{h @index}">\n]
@@ -22,3 +23,10 @@ def calendar
 	result << %Q[<input type="submit" value="Go">\n]
 	result << "</div>\n</form>"
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
