@@ -1,5 +1,5 @@
 =begin
-= A little bit more powerful display of referrers((-$Id: disp_referrer.rb,v 1.19 2007/12/07 13:34:17 zunda Exp $-))
+= A little bit more powerful display of referrers((-$Id: disp_referrer.rb,v 1.20 2008-03-02 09:01:46 kazuhiko Exp $-))
 English resource
 
 == Copyright notice
@@ -34,22 +34,22 @@ See ../ChangeLog for changes after this.
 - instance_eval for e[2] in the search engine list
 * Wed Aug  7, 2003 zunda <zunda at freeshell.org>
 - WWW browser configuration interface
-  - åιμ¤ˤ褦ˤޤWWW֥饦ִ
-    ꥹȤäˤϥꥹȤκǽɲäޤ
-  - secure=trueǤ¾Υ󥯸ꥹȤɽǤ褦ˤʤޤ
+  - キャッシュの更新をより確実にするようにしました。WWWブラウザから置換
+    リストを作った場合にはリストの最初に追加されます。
+  - secure=trueな日記でその他のリンク元リストが表示できるようになりました。
 - Regexp generation for Wiki sites
 * Wed Aug  6, 2003 zunda <zunda at freeshell.org>
 - WWW browser configuration interface
-  - ʥץȥ󥯸ִꥹȤθΨŪԽWWW֥饦
-    褦ˤʤޤsecure=trueǤϰεǽϻȤޤ
+  - 主なオプションとリンク元置換リストの効率的な編集がWWWブラウザからで
+    きるようになりました。secure=trueな日記では一部の機能は使えません。
 * Sat Aug  2, 2003 zunda <zunda at freeshell.org>
 - Second version
 - basic functions re-implemented
-  - ץ̿̾ʤޤޤפʥץäޤ
-    tdiary.confԽƤϡǤ򤷤ʤƤ
-  - Nora饤֥ȥåѤǹ®ޤ
-  - 󥸥ΥꥹȤץ饰ǻĤ褦ˤʤޤ&;ޤม
-    ʸ̤ФǤޤ
+  - オプションを命名しなおしました。また不要なオプションを消しました。
+    tdiary.confを編集していた方は、お手数ですが設定をしなおしてください。
+  - Noraライブラリとキャッシュの利用で高速化しました。
+  - 検索エンジンのリストをプラグインで持つようになりました。&や;を含む検
+    索文字列も期待通りに抽出できます。
 * Mon Feb 17, 2003 zunda <zunda at freeshell.org>
 - First version
 =end
@@ -313,7 +313,7 @@ DispReferrer2_Engines = {
 	'metabot' => [[%r{\Ahttp://.*?\.metabot\.ru}i, '"MetaBot.ru"', ['st'], nil ]],
 	'altavista' => [[%r{\Ahttp://.*?\.altavista\.([^/]+)}i, '"Altavista in .#{$1}"', ['q'], nil ]],
 	'infoseek' => [[%r{\Ahttp://(www\.)?infoseek\.co\.jp}i, '"Infoseek"', ['qt'], nil ]],
-	'odn' => [[%r{\Ahttp://.*?\.odn\.ne\.jp}i, '"ODN"', ['QueryString', 'key'], nil ]],
+	'odn' => [[%r{\Ahttp://.*?\.odn\.ne\.jp}i, '"ODN検索"', ['QueryString', 'key'], nil ]],
 	'lycos' => [[%r{\Ahttp://.*?\.lycos\.([^/]+)}i, '"Lycos in .#{$1}"', ['query', 'q', 'qt'], nil ]],
 	'fresheye' => [[%r{\Ahttp://.*?\.fresheye}i, '"Fresheye"', ['kw'], nil ]],
 	'goo' => [
@@ -376,3 +376,10 @@ DispReferrer2_Engines = {
 	'planet' => [[%r{\Ahttp://www\.planet\.nl/planet/}i, '"Planet-Zoekpagina"', ['googleq', 'keyword'], DispReferrer2_Google_cache]], # googleq parameter has a strange prefix
 	'216' => [[%r{\Ahttp://(\d+\.){3}\d+/search}i, '"Google?"', ['as_q', 'q'], DispReferrer2_Google_cache]],	# cache servers of google?
 }
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
