@@ -1,9 +1,10 @@
-# footnote.rb $Revision: 1.14 $
+# -*- coding: utf-8 -*-
+# footnote.rb
 #
-# fn: plugin
-#   ѥ᥿:
-#     text: ʸ
-#     mark: ޡ('*')
+# fn: 脚注plugin
+#   パラメタ:
+#     text: 脚注本文
+#     mark: 脚注マーク('*')
 #
 # Copyright (C) 2007 TADA Tadashi <sho@spc.gr.jp>
 # Distributed under the GPL.
@@ -39,7 +40,7 @@ def fn( text, mark = '*' )
 		r << %Q|name="#{@fn_fragment_fm % idx}" |
 		r << %Q|href="##{@fn_fragment_f % idx}" |
 		r << %Q|title="#{h text}">|
-		r << %Q|#{mark}#{idx}|
+		r << %Q|#{h mark}#{idx}|
 		r << %Q|</a>|
 	end
 	r << %Q|</span>|
@@ -77,4 +78,10 @@ def fn_put
 	end
 end
 
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
 # vim: ts=3
