@@ -1,50 +1,51 @@
-# image.rb $Revision: 1.34 $
+# -*- coding: utf-8 -*-
+# image.rb
 # -pv-
 # 
-# ̾:
-# Plugin
+# 名称:
+# 絵日記Plugin
 #
-# :
-# ̤βåץɡʸؤɽ
+# 概要:
+# 日記更新画面からの画像アップロード、本文への表示
 #
-# Ȥ:
-# ʸ
+# 使う場所:
+# 本文
 #
-# Ȥ:
-# image( number, 'altword', thumbnail, size, place ) - ɽޤ
-#    number - ֹ012
-#    altword - img altʸ
-#    thumbnail - ͥ(ʲ)ꤹ(ά)
-#    size - Υ(Array)[width, height]ηǻ(ά)
-#    place - imgclass̾(ά)ά'photo'
+# 使い方:
+# image( number, 'altword', thumbnail, size, place ) - 画像を表示します。
+#    number - 画像の番号0、1、2等
+#    altword - imgタグの altに入れる文字列
+#    thumbnail - サムネイル(小さな画像)を指定する(省略可)
+#    size - 画像のサイズ(Array)。[width, height]の形式で指定(省略可)
+#    place - imgタグのclass名(省略可)。省略時は'photo'
 #
-# image_left( number, 'altword', thumbnail, size ) - imageclass=leftɲäޤ
-# image_right( number, 'altword', thumbnail, size ) - imageclass=rightɲäޤ
+# image_left( number, 'altword', thumbnail, size ) - imageにclass=leftを追加します。
+# image_right( number, 'altword', thumbnail, size ) - imageにclass=rightを追加します。
 #
-# image_link( number, 'desc' ) - ؤΥ󥯤ޤ
-#    number - ֹ012
-#    desc - 
+# image_link( number, 'desc' ) - 画像へのリンクを生成します。
+#    number - 画像の番号0、1、2等
+#    desc - 画像の説明
 #
-# ¾:
-# tDiary version 1.5.4ʹߤưޤ
-# tdiary.confǻǤ륪ץ:
+# その他:
+# tDiary version 1.5.4以降で動作します。
+# tdiary.confで指定できるオプション:
 #  @options['image.dir']
-#     ե¸ǥ쥯ȥꡣ̵'./images/'
-#     WebФθ¤ǽ񤭹褦ˤƤɬפޤ
+#     画像ファイルを保存するディレクトリ。無指定時は'./images/'
+#     Webサーバの権限で書き込めるようにしておく必要があります。
 #  @options['image.url']
-#     ե¸ǥ쥯ȥURL̵'./images/'
+#     画像ファイルを保存するディレクトリのURL。無指定時は'./images/'
 #  @options['image.maxnum']
-#     1κ̵1
-#     @secure = trueΤͭ
+#     1日あたりの最大画像数。無指定時は1
+#     ただし@secure = true時のみ有効
 #  @options['image.maxsize']
-#     1礢κХȿ̵10000
-#     @secure = trueΤͭ
+#     1枚あたりの最大画像バイト数。無指定時は10000
+#     ただし@secure = true時のみ有効
 #  @options['image.maxwidth']
-#     sizeꤷʤä˻Ǥκɽ̵nil
-#     ɽΤӤ˥ե륢ΤǡŤʤ뤫?
-#     @secure = true̵
+#     sizeを指定しなかった場合に指定できる画像の最大表示幅。無指定時はnil
+#     表示のたびにファイルアクセスが入るので、重くなるかも?
+#     @secure = true時は無効
 #
-# 饤󥹤ˤĤ:
+# ライセンスについて:
 # Copyright (c) 2002,2003 Daisuke Kato <dai@kato-agri.com>
 # Copyright (c) 2002 Toshi Okada <toshi@neverland.to>
 # Copyright (c) 2003 Yoshimi KURUMA <yoshimik@iris.dti.ne.jp>
@@ -52,15 +53,15 @@
 #
 
 unless @resource_loaded then
-	def image_error_num( max ); "1#{h max}ޤǤǤפʲƤɲäƤ"; end
-	def image_error_size( max ); "κ祵#{h max}ХȤޤǤǤ"; end
-	def image_label_list_caption; '()'; end
-	def image_label_add_caption; '(ɲ)'; end
-	def image_label_description; ''; end
-	def image_label_add_plugin; 'ʸɲ'; end
-	def image_label_delete; 'åκ'; end
-	def image_label_only_jpeg; 'JPEGΤ'; end
-	def image_label_add_image; 'β򥢥åץɤ'; end
+	def image_error_num( max ); "画像は1日#{h max}枚までです。不要な画像を削除してから追加してください"; end
+	def image_error_size( max ); "画像の最大サイズは#{h max}バイトまでです"; end
+	def image_label_list_caption; '絵日記(一覧・削除)'; end
+	def image_label_add_caption; '絵日記(追加)'; end
+	def image_label_description; '画像の説明'; end
+	def image_label_add_plugin; '本文に追加'; end
+	def image_label_delete; 'チェックした画像の削除'; end
+	def image_label_only_jpeg; 'JPEGのみ'; end
+	def image_label_add_image; 'この画像をアップロードする'; end
 end
 
 def image( id, alt = 'image', thumbnail = nil, size = nil, place = 'photo' )
@@ -71,10 +72,11 @@ def image( id, alt = 'image', thumbnail = nil, size = nil, place = 'photo' )
    	image = image_list( @image_date )[id.to_i]
    	image_t = image_list( @image_date )[thumbnail.to_i] if thumbnail
 	end
-	if size then
+	if @conf.iphone? then
+		size = ''
+	elsif size
 		if size.kind_of?(Array)
 			size = %Q| width="#{h size[0]}" height="#{h size[1]}"|
-
 		else
 			size = %Q| width="#{size.to_i}"|
 		end
@@ -136,15 +138,15 @@ def image_info( f )
 	image_width = nil
 
 	sig = f.read( 24 )
-	if /\A\x89PNG\x0D\x0A\x1A\x0A(....)IHDR(........)/on =~ sig
+	if /\A\x89PNG\x0D\x0A\x1A\x0A(....)IHDR(........)/onm =~ sig
 		image_type = 'png'
 		image_width, image_height = $2.unpack( 'NN' )
 
-	elsif /\AGIF8[79]a(....)/on =~ sig
+	elsif /\AGIF8[79]a(....)/onm =~ sig
 		image_type   = 'gif'
 		image_width, image_height = $1.unpack( 'vv' )
 
-	elsif /\A\xFF\xD8/on =~ sig
+	elsif /\A\xFF\xD8/onm =~ sig
 		image_type = 'jpg'
 		data = $'
 		until data.empty?
@@ -184,7 +186,8 @@ def image_list( date )
 	list = []
 	reg = /#{date}_(\d+)\.(#{image_ext})$/
 	begin
-		Dir::foreach( @image_dir ) do |file|
+		Dir::glob( @image_dir + "/#{date}_*" ) do |file|
+			file = File.basename( file )
 			list[$1.to_i] = file if reg =~ file
 		end
 	rescue Errno::ENOENT
@@ -238,34 +241,35 @@ if /^formplugin$/ =~ @mode then
 	end
 end
 
+add_header_proc do
+	%Q[\t<script type="text/javascript"><!--
+	var elem=null
+	function insertImage(val){
+		elem.value+=val
+	}
+	window.onload=function(){
+		for(var i=0;i<document.forms.length;i++){
+			for(var j=0;j<document.forms[i].elements.length;j++){
+				var e=document.forms[i].elements[j]
+				if(e.type&&e.type=="textarea"){
+					if(elem==null){
+						elem=e
+					}
+					e.onfocus=new Function("elem=this")
+				}
+			}
+		}
+	}
+	//-->
+	</script>
+	]
+end
+
 add_form_proc do |date|
 	r = ''
 	tabidx = 1200
 	images = image_list( date.strftime( '%Y%m%d' ) )
 	if images.length > 0 then
-		r << %Q[
-		<script type="text/javascript">
-		<!--
-		var elem=null
-		function ins(val){
-			elem.value+=val
-		}
-		window.onload=function(){
-			for(var i=0;i<document.forms.length;i++){
-				for(var j=0;j<document.forms[i].elements.length;j++){
-					var e=document.forms[i].elements[j]
-					if(e.type&&e.type=="textarea"){
-						if(elem==null){
-							elem=e
-						}
-						e.onfocus=new Function("elem=this")
-					}
-				}
-			}
-		}
-		//-->
-		</script>
-		]
 		case @conf.style.sub( /^blog/i, '' )
                 when /^wiki|markdown$/i
 			ptag1 = "{{"
@@ -306,7 +310,7 @@ add_form_proc do |date|
 			tmp << %Q[<td>
 			#{img_info}<br>
 			<input type="checkbox" tabindex="#{tabidx+id*2}" name="plugin_image_id" value="#{h id}">#{id}
-			<input type="button" tabindex="#{tabidx+id*2+1}" onclick="ins(&quot;#{ptag}&quot;)" value="#{image_label_add_plugin}">
+			<input type="button" tabindex="#{tabidx+id*2+1}" onclick="insertImage(&quot;#{ptag}&quot;)" value="#{image_label_add_plugin}">
 			</td>]
 	   end
 		r << "</tr><tr>"
@@ -337,3 +341,10 @@ add_form_proc do |date|
    </div></form>
 	</div>]
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
