@@ -1,4 +1,4 @@
-# makerss.rb: $Revision: 1.58 $
+# makerss.rb
 #
 # generate RSS file when updating.
 #
@@ -24,7 +24,7 @@
 #   CAUTION: Before using, make 'index.rdf' and 'no_comments.rdf' file
 #            into the directory of your diary, and permit writable to httpd.
 #
-# Copyright (c) 2004 TADA Tadashi <sho@spc.gr.jp>
+# Copyright (c) 2009 TADA Tadashi <t@tdtds.jp>
 # Distributed under the GPL
 #
 
@@ -32,31 +32,29 @@ if /^append|replace|comment|showcomment|trackbackreceive|pingbackreceive$/ =~ @m
 	unless @conf.description
 		@conf.description = @conf['whatsnew_list.rdf.description']
 	end
-	eval( <<-TOPLEVEL_CLASS, TOPLEVEL_BINDING )
-		module TDiary
-			class RDFSection
-				attr_reader :id, :time, :section, :diary_title
+	module ::TDiary
+		class RDFSection
+			attr_reader :id, :time, :section, :diary_title
 
-				# 'id' has 'YYYYMMDDpNN' format (p or c).
-				# 'time' is Last-Modified this section as a Time object.
-				def initialize( id, time, section )
-					@id, @time, @section, @diary_title = id, time, section, diary_title
-				end
+			# 'id' has 'YYYYMMDDpNN' format (p or c).
+			# 'time' is Last-Modified this section as a Time object.
+			def initialize( id, time, section )
+				@id, @time, @section, @diary_title = id, time, section, diary_title
+			end
 
-				def time_string
-					g = @time.dup.gmtime
-					l = Time::local( g.year, g.month, g.day, g.hour, g.min, g.sec )
-					tz = (g.to_i - l.to_i)
-					zone = sprintf( "%+03d:%02d", tz / 3600, tz % 3600 / 60 )
-					@time.strftime( "%Y-%m-%dT%H:%M:%S" ) + zone
-				end
+			def time_string
+				g = @time.dup.gmtime
+				l = Time::local( g.year, g.month, g.day, g.hour, g.min, g.sec )
+				tz = (g.to_i - l.to_i)
+				zone = sprintf( "%+03d:%02d", tz / 3600, tz % 3600 / 60 )
+				@time.strftime( "%Y-%m-%dT%H:%M:%S" ) + zone
+			end
 
-				def <=>( other )
-					other.time <=> @time
-				end
+			def <=>( other )
+				other.time <=> @time
 			end
 		end
-	TOPLEVEL_CLASS
+	end
 end
 
 @makerss_rsses = @makerss_rsses || []
@@ -286,7 +284,7 @@ def makerss_header( uri )
 	<channel rdf:about="#{h rdf_url}">
 	<title>#{h @conf.html_title}</title>
 	<link>#{h uri}</link>
-	<xhtml:link rel="alternate" media="handheld" type="text/html" href="#{h uri}" />
+	<xhtml:link xhtml:rel="alternate" xhtml:media="handheld" xhtml:type="text/html" xhtml:href="#{h uri}" />
 	<description>#{h desc}</description>
 	<dc:creator>#{h @conf.author_name}</dc:creator>
 	<dc:rights>#{h copyright}</dc:rights>
@@ -326,7 +324,7 @@ def makerss_body( uri, rdfsec )
 	if rdfsec.section.respond_to?( :body_to_html ) then
 		rdf = %Q|<item rdf:about="#{h uri}#{anchor rdfsec.id}">\n|
 		rdf << %Q|<link>#{h uri}#{anchor rdfsec.id}</link>\n|
-		rdf << %Q|<xhtml:link rel="alternate" media="handheld" type="text/html" href="#{h uri}#{anchor rdfsec.id}" />\n|
+		rdf << %Q|<xhtml:link xhtml:rel="alternate" xhtml:media="handheld" xhtml:type="text/html" xhtml:href="#{h uri}#{anchor rdfsec.id}" />\n|
 		rdf << %Q|<dc:date>#{h rdfsec.time_string}</dc:date>\n|
 		a = rdfsec.id.scan( /(\d{4})(\d\d)(\d\d)/ ).flatten.map{|s| s.to_i}
 		date = Time::local( *a )
@@ -341,8 +339,8 @@ def makerss_body( uri, rdfsec )
 		body_leave = body_leave_proc( date )
 		@makerss_in_feed = false
 
-		sub = apply_plugin( subtitle, true ).strip
-		sub.sub!( /^(\[([^\]]+)\])+ */, '' )
+		sub = (subtitle || '').sub( /^(\[([^\]]+)\])+ */, '' )
+		sub = apply_plugin( sub, true ).strip
 		if sub.empty?
 			sub = @conf.shorten( remove_tag( body ).strip, 20 )
 		end
@@ -363,16 +361,17 @@ def makerss_body( uri, rdfsec )
 			text << body
 			text << body_leave
 			unless text.empty?
+				uri = @conf.index.dup
+				uri[0, 0] = @conf.base_url unless %r|^https?://|i =~ uri
+				uri.gsub!( %r|/\./|, '/' )
+				text = absolutify( text, uri )
 				text.gsub!( /\]\]>/, ']]]]><![CDATA[>' )
 				rdf << %Q|<content:encoded><![CDATA[#{text}|
-            unless @conf['makerss.comment_link']
-               ymd = date.strftime( "%Y%m%d" )
-               uri = @conf.index.dup
-               uri[0, 0] = @conf.base_url unless %r|^https?://|i =~ uri
-               uri.gsub!( %r|/\./|, '/' )
-               rdf << %Q|\n<p><a href="#{h uri}#{anchor "#{ymd}c"}">#{comment_new}</a></p>|
-            end
-            rdf << %Q|]]></content:encoded>\n|
+				unless @conf['makerss.comment_link']
+					ymd = date.strftime( "%Y%m%d" )
+					rdf << %Q|\n<p><a href="#{h uri}#{anchor "#{ymd}c"}">#{comment_new}</a></p>|
+				end
+				rdf << %Q|]]></content:encoded>\n|
 			end
 		end
 
@@ -430,7 +429,13 @@ add_conf_proc( 'makerss', @makerss_conf_label, 'update' ) do
 end
 
 add_edit_proc do
-	checked = @cgi.params['makerss_update'][0] == 'false' ? ' checked' : ''
+	checked = if @cgi.params['makerss_update'][0] == 'false' then
+		' checked'
+	elsif @date < (Time::now - 30*24*60*60) # older over a month
+		' checked'
+	else
+		''
+	end
 	r = <<-HTML
 	<div class="makerss"><label for="makerss_update">
 	<input type="checkbox" id="makerss_update" name="makerss_update" value="false"#{checked} tabindex="390">
@@ -474,37 +479,37 @@ def replace_entities( text )
 			'&frac12;' => '&#189;',
 			'&frac34;' => '&#190;',
 			'&iquest;' => '&#191;',
-			'&agrave;' => '&#192;',
-			'&aacute;' => '&#193;',
-			'&acirc;' => '&#194;',
-			'&atilde;' => '&#195;',
-			'&auml;' => '&#196;',
-			'&aring;' => '&#197;',
-			'&aelig;' => '&#198;',
-			'&ccedil;' => '&#199;',
-			'&egrave;' => '&#200;',
-			'&eacute;' => '&#201;',
-			'&ecirc;' => '&#202;',
-			'&euml;' => '&#203;',
-			'&igrave;' => '&#204;',
-			'&iacute;' => '&#205;',
-			'&icirc;' => '&#206;',
-			'&iuml;' => '&#207;',
-			'&eth;' => '&#208;',
-			'&ntilde;' => '&#209;',
-			'&ograve;' => '&#210;',
-			'&oacute;' => '&#211;',
-			'&ocirc;' => '&#212;',
-			'&otilde;' => '&#213;',
-			'&ouml;' => '&#214;',
+			'&Agrave;' => '&#192;',
+			'&Aacute;' => '&#193;',
+			'&Acirc;' => '&#194;',
+			'&Atilde;' => '&#195;',
+			'&Auml;' => '&#196;',
+			'&Aring;' => '&#197;',
+			'&Aelig;' => '&#198;',
+			'&Ccedil;' => '&#199;',
+			'&Egrave;' => '&#200;',
+			'&Eacute;' => '&#201;',
+			'&Ecirc;' => '&#202;',
+			'&Euml;' => '&#203;',
+			'&Igrave;' => '&#204;',
+			'&Iacute;' => '&#205;',
+			'&Icirc;' => '&#206;',
+			'&Iuml;' => '&#207;',
+			'&ETH;' => '&#208;',
+			'&Ntilde;' => '&#209;',
+			'&Ograve;' => '&#210;',
+			'&Oacute;' => '&#211;',
+			'&Ocirc;' => '&#212;',
+			'&Otilde;' => '&#213;',
+			'&Ouml;' => '&#214;',
 			'&times;' => '&#215;',
-			'&oslash;' => '&#216;',
-			'&ugrave;' => '&#217;',
-			'&uacute;' => '&#218;',
-			'&ucirc;' => '&#219;',
-			'&uuml;' => '&#220;',
-			'&yacute;' => '&#221;',
-			'&thorn;' => '&#222;',
+			'&Oslash;' => '&#216;',
+			'&Ugrave;' => '&#217;',
+			'&Uacute;' => '&#218;',
+			'&Ucirc;' => '&#219;',
+			'&Uuml;' => '&#220;',
+			'&Yacute;' => '&#221;',
+			'&THORN;' => '&#222;',
 			'&szlig;' => '&#223;',
 			'&agrave;' => '&#224;',
 			'&aacute;' => '&#225;',
@@ -561,36 +566,36 @@ def replace_entities( text )
 			'&rdquo;' => '&#8221;',
 			'&bdquo;' => '&#8222;',
 			'&dagger;' => '&#8224;',
-			'&dagger;' => '&#8225;',
+			'&Dagger;' => '&#8225;',
 			'&permil;' => '&#8240;',
 			'&lsaquo;' => '&#8249;',
 			'&rsaquo;' => '&#8250;',
 			'&euro;' => '&#8364;',
 			'&fnof;' => '&#402;',
-			'&alpha;' => '&#913;',
-			'&beta;' => '&#914;',
-			'&gamma;' => '&#915;',
-			'&delta;' => '&#916;',
-			'&epsilon;' => '&#917;',
-			'&zeta;' => '&#918;',
-			'&eta;' => '&#919;',
-			'&theta;' => '&#920;',
-			'&iota;' => '&#921;',
-			'&kappa;' => '&#922;',
-			'&lambda;' => '&#923;',
-			'&mu;' => '&#924;',
-			'&nu;' => '&#925;',
-			'&xi;' => '&#926;',
-			'&omicron;' => '&#927;',
-			'&pi;' => '&#928;',
-			'&rho;' => '&#929;',
-			'&sigma;' => '&#931;',
-			'&tau;' => '&#932;',
-			'&upsilon;' => '&#933;',
-			'&phi;' => '&#934;',
-			'&chi;' => '&#935;',
-			'&psi;' => '&#936;',
-			'&omega;' => '&#937;',
+			'&Alpha;' => '&#913;',
+			'&Beta;' => '&#914;',
+			'&Gamma;' => '&#915;',
+			'&Delta;' => '&#916;',
+			'&Epsilon;' => '&#917;',
+			'&Zeta;' => '&#918;',
+			'&Eta;' => '&#919;',
+			'&Theta;' => '&#920;',
+			'&Iota;' => '&#921;',
+			'&Kappa;' => '&#922;',
+			'&Lambda;' => '&#923;',
+			'&Mu;' => '&#924;',
+			'&Nu;' => '&#925;',
+			'&Xi;' => '&#926;',
+			'&Omicron;' => '&#927;',
+			'&Pi;' => '&#928;',
+			'&Rho;' => '&#929;',
+			'&Sigma;' => '&#931;',
+			'&Tau;' => '&#932;',
+			'&Upsilon;' => '&#933;',
+			'&Phi;' => '&#934;',
+			'&Chi;' => '&#935;',
+			'&Psi;' => '&#936;',
+			'&Omega;' => '&#937;',
 			'&alpha;' => '&#945;',
 			'&beta;' => '&#946;',
 			'&gamma;' => '&#947;',
@@ -635,11 +640,11 @@ def replace_entities( text )
 			'&darr;' => '&#8595;',
 			'&harr;' => '&#8596;',
 			'&crarr;' => '&#8629;',
-			'&larr;' => '&#8656;',
-			'&uarr;' => '&#8657;',
-			'&rarr;' => '&#8658;',
-			'&darr;' => '&#8659;',
-			'&harr;' => '&#8660;',
+			'&lArr;' => '&#8656;',
+			'&uArr;' => '&#8657;',
+			'&rArr;' => '&#8658;',
+			'&dArr;' => '&#8659;',
+			'&hArr;' => '&#8660;',
 			'&forall;' => '&#8704;',
 			'&part;' => '&#8706;',
 			'&exist;' => '&#8707;',
@@ -692,6 +697,47 @@ def replace_entities( text )
 		}
 	end
 	text.gsub( /&[a-z]+;/im ) do |e|
-		@xml_entity_table[e.downcase] || e
+		@xml_entity_table[e] || e
 	end
 end
+
+# Copied from below which includes some tests
+# http://github.com/zunda/ruby-absolutify/tree/master
+def absolutify(html, baseurl)
+	@@_absolutify_attr_regexp ||= Hash.new
+	baseuri = URI.parse(URI.encode(baseurl))
+	r = html.gsub(%r|<\S[^>]*/?>|) do |tag|
+		type = tag.scan(/\A<(\S+)/)[0][0].downcase
+		if attr = {'a' => 'href', 'img' => 'src'}[type]
+			@@_absolutify_attr_regexp[attr] ||= %r|(.*#{attr}\s*=\s*)(['"]?)([^\2>]+?)(\2.*)|im
+			m = tag.match(@@_absolutify_attr_regexp[attr])
+			unless m.nil?
+				prefix = m[1] + m[2]
+				location = m[3]
+				postfix = m[4]
+				begin
+					uri = URI.parse(location)
+					if uri.relative?
+						location = (baseuri + location).to_s
+					elsif not uri.host
+						path = uri.path
+						path += '?' + uri.query if uri.query
+						path += '#' + uri.fragment if uri.fragment
+						location = (baseuri + path).to_s
+					end
+					tag = prefix + location + postfix
+				rescue URI::InvalidURIError
+				end
+			end
+		end
+		tag
+	end
+	return r
+end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
