@@ -1,12 +1,14 @@
-# $Revision: 1.37 $
-# recent_comment3: ǶΥĥåߤꥹȥåפ
+# -*- coding: utf-8 -*-
 #
-#	 @secure = true ʴĶǤưޤ
+# recent_comment3: 最近のツッコミをリストアップする
+#
+#   @secure = true な環境では動作しません．
 #
 # Copyright (c) 2002 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
 #
 require 'pstore'
+require 'fileutils'
 require 'time'
 
 def recent_comment3_format(format, *args)
@@ -14,7 +16,15 @@ def recent_comment3_format(format, *args)
 end
 
 def recent_comment3_init
-	@conf['recent_comment3.cache'] ||= "#{@cache_path}/recent_comments"
+	# backward compatibility
+	if File.exists?( "#{@cache_path}/recent_comments" ) then
+		FileUtils.mv( "#{@cache_path}/recent_comments", "#{@conf.data_path}/recent_comments" )
+	end
+	if @conf['recent_comment3.cache'] == "#{@cache_path}/recent_comments" then
+		@conf['recent_comment3.cache'] = "#{@conf.data_path}/recent_comments"
+	end
+
+	@conf['recent_comment3.cache'] ||= "#{@conf.data_path}/recent_comments"
 	@conf['recent_comment3.cache_size'] ||= 50
 	@conf['recent_comment3.max'] ||= 3
 	@conf['recent_comment3.date_format'] ||= "(%m-%d)"
@@ -22,6 +32,7 @@ def recent_comment3_init
 	@conf['recent_comment3.format'] ||= '<a href="$2" title="$3">$4 $5</a>'
 	@conf['recent_comment3.tree'] ||= ""
 	@conf['recent_comment3.titlelen'] ||= 20
+	@conf['recent_comment.notfound_msg'] ||= ''
 end
 
 def recent_comment3(ob_max = 'OBSOLUTE' ,sep = 'OBSOLUTE',ob_date_format = 'OBSOLUTE',*ob_except )
@@ -35,6 +46,7 @@ def recent_comment3(ob_max = 'OBSOLUTE' ,sep = 'OBSOLUTE',ob_date_format = 'OBSO
 	except = @conf['recent_comment3.except_list'].split(/,/)
 	format = @conf['recent_comment3.format']
 	titlelen = @conf['recent_comment3.titlelen']
+	notfound_msg = @conf['recent_comment.notfound_msg']
 	
 	entries = {}
 	tree_order =[]
@@ -75,7 +87,7 @@ def recent_comment3(ob_max = 'OBSOLUTE' ,sep = 'OBSOLUTE',ob_date_format = 'OBSO
 	
 	if @conf['recent_comment3.tree'] == "t" then
 		if entries.size == 0
-			''
+			notfound_msg
 		else
 			cgi = CGI::new
 			def cgi.referer; nil; end
@@ -88,7 +100,7 @@ def recent_comment3(ob_max = 'OBSOLUTE' ,sep = 'OBSOLUTE',ob_date_format = 'OBSO
 				if diary != nil then
 					title = diary.diaries[entry_date].title.gsub( /<[^>]*>/, '' )
 				end
-				if title == nil || title.length == 0 || title.strip.delete('').delete(' ').length == 0 then
+				if title == nil || title.length == 0 || title.strip.delete('　').delete(' ').length == 0 then
 					date = Time.parse(entry_date)
 					title = "#{date.strftime @date_format}"
 				end
@@ -162,7 +174,14 @@ if @mode == 'saveconf'
 		@conf['recent_comment3.format'] = @cgi.params['recent_comment3.format'][0]
 		@conf['recent_comment3.tree'] = @cgi.params['recent_comment3.tree'][0]
 		@conf['recent_comment3.titlelen'] = @cgi.params['recent_comment3.titlelen'][0].to_i
-   end
+		@conf['recent_comment.notfound_msg'] = @cgi.params['recent_comment.notfound_msg'][0]
+	end
 end
 
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
 # vim: ts=3
