@@ -1,12 +1,12 @@
-# tb-send.rb $Revision: 1.25 $
+# tb-send.rb
 #
 # Copyright (c) 2003 Junichiro Kita <kita@kitaj.no-ip.com>
 # You can distribute this file under the GPL.
 #
 
 add_edit_proc do |date|
-	url = @cgi.params['plugin_tb_url'][0] || ''
-	excerpt = @cgi.params['plugin_tb_excerpt'][0] || ''
+	url =  @conf.to_native( @cgi.params['plugin_tb_url'][0] || '' )
+	excerpt =  @conf.to_native( @cgi.params['plugin_tb_excerpt'][0] || '' )
 	section = @cgi.params['plugin_tb_section'][0] || ''
 	select_sections = ''
 	unless @conf['tb.no_section'] then
@@ -137,4 +137,14 @@ def tb_send_trackback
 	end
 end
 
+def tb_send_utf8( str )
+	@conf.to_native( str )
+end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
 # vim: ts=3
