@@ -18,13 +18,12 @@
 # CODE.
 
 # title_tag2.rb to enhance <title> element of generating HTML
-# $Id: title_tag.rb,v 1.5 2007/01/09 13:36:06 hsbt Exp $
+# $Id: title_tag.rb,v 1.6 2008-03-02 09:01:45 kazuhiko Exp $
 # To use, just put this file into plugin folder.
 
 alias :title_tag2 :title_tag
 
-eval(<<__END_OF_TOPLEVEL__,TOPLEVEL_BINDING)
-module TDiary
+module ::TDiary
 	module DiaryBase
 		def all_subtitles_to_html
 			titles = Array.new
@@ -43,24 +42,24 @@ module TDiary
 		end
 	end
 end
-__END_OF_TOPLEVEL__
 
 def title_tag
 	if @mode == 'day' and diary = @diaries[@date.strftime('%Y%m%d')] then
 		if !diary.visible? then
 			return title_tag2
 		end
-		title = @html_title + ' - '
+		site_title = " - #{title_tag2.gsub( /<.*?>/, '')}"
+		day_title = ''
 		if  !diary.title.empty? then
-			title << apply_plugin(diary.title, true) << ' - '
+			day_title << apply_plugin(diary.title, true) << ':'
 		end
 		t2 = ''
 		if @plugin_files.grep(/\/category.rb$/).empty? then
-			t2 << diary.all_subtitles_to_html.join(' , ')
+			t2 << diary.all_subtitles_to_html.join(', ')
 		else
-			t2 << diary.all_stripped_subtitles_to_html.join(' , ')
+			t2 << diary.all_stripped_subtitles_to_html.join(', ')
 		end
-		return "<title>#{h( title )}#{h( @conf.shorten(apply_plugin(t2, true)) )}</title>"
+		return "<title>#{h day_title}#{h( @conf.shorten(apply_plugin(t2, true)) )}#{h( site_title )}</title>"
 	elsif @mode == 'categoryview' then
 		return @conf.shorten("<title>#{h( @html_title )}#{h( category_title() )}</title>")
 	else
@@ -70,11 +69,11 @@ end
 
 # Local Variables:
 # mode: ruby
-# code: euc-jp-unix
+# code: utf-8
 # indent-tabs-mode: t
 # tab-width: 3
 # ruby-indent-level: 3
 # fill-column: 79
 # default-justification: full
 # End:
-# vi: ts=3 sw=3
\ No newline at end of file
+# vi: ts=3 sw=3
