@@ -1,5 +1,5 @@
 #!/usr/bin/env ruby
-# tb.rb $Revision: 1.12 $
+# tb.rb
 #
 # Copyright (c) 2003 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
@@ -7,7 +7,7 @@
 # derived from sheepman's tb.rb. Thanks to sheepman <sheepman@tcn.zaq.ne.jp>
 # 
 
-BEGIN { $defout.binmode }
+BEGIN { $stdout.binmode }
 $KCODE = 'n'
 
 begin
@@ -72,4 +72,11 @@ rescue Exception
 	puts "</pre>"
 	puts "<div>#{' ' * 500}</div>"
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
 # vim: ts=3
