@@ -1,4 +1,4 @@
-# ja/category.rb $Revision: 1.6 $
+# ja/category.rb
 #
 # Copyright (c) 2004 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
@@ -136,7 +136,7 @@ HTML
 <tr>
 	<td>#{button}</td>
 	<td><input type="text" name="#{name}" value="#{h @conf[name]}" size="30"></td>
-	<td><p><span class="adminmenu"><a>#{@conf[name].sub(/\$1/, "2007").sub(/\$2/, "2")}</a></span></p></td>
+	<td><p><span class="adminmenu"><a>#{h @conf[name].sub(/\$1/, "2007").sub(/\$2/, "2")}</a></span></p></td>
 </tr>
 HTML
 	end
@@ -193,4 +193,11 @@ Move mouse pointer on an icon, the icon's name will pop up.
 </p>
 HTML
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
 # vim: ts=3
