@@ -1,5 +1,6 @@
+# -*- coding: utf-8 -*-
 #
-# English resource of image plugin $Revision: 1.2 $
+# English resource of image plugin
 #
 
 #
@@ -30,12 +31,19 @@
 #     Max size of an image. Default is 10000 bytes.
 #     This option is effective in @secure = true.
 #
-def image_error_num( max ); "Chx̦hiK #{h max} iϤ"; end
-def image_error_size( max ); "CiϤ̤j #{h max} bytes"; end
-def image_label_list_caption; 'CXΧRϤ'; end
-def image_label_add_caption; '[Ϥ'; end
-def image_label_description; 'Ϥ'; end
-def image_label_add_plugin; '[峹'; end
-def image_label_delete; 'NϤR'; end
-def image_label_only_jpeg; 'u JPEG 榡'; end
-def image_label_add_image; 'WǹϤ'; end
+def image_error_num( max ); "每則日誌最多可貼 #{h max} 張圖片"; end
+def image_error_size( max ); "每張圖片最大限制為 #{h max} bytes"; end
+def image_label_list_caption; '列出或刪除圖片'; end
+def image_label_add_caption; '附加圖片'; end
+def image_label_description; '圖片的附註'; end
+def image_label_add_plugin; '附加到文章當中'; end
+def image_label_delete; '將選取的圖片刪除'; end
+def image_label_only_jpeg; '只接受 JPEG 格式'; end
+def image_label_add_image; '上傳圖片'; end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
