@@ -1,11 +1,31 @@
+# -*- coding: utf-8; -*-
 #
 # 00default.rb: default plugins 
-# $Revision: 1.119 $
 #
-# Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+# Copyright (C) 2010, TADA Tadashi <t@tdtds.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
 
+#
+# setting @date
+#
+unless @date
+	if @diary then
+		@date = @diary.date
+	else
+		@date = case @mode
+		when 'day'
+			Time::local( *@cgi.params['date'][0].scan( /^(\d{4})(\d\d)(\d\d)/ ).flatten )
+		when 'month'
+			Time::local( *@cgi.params['date'][0].scan( /^(\d{4})(\d\d)/ ).flatten )
+		when 'edit'
+			Time::local( @cgi.params['year'][0].to_i, @cgi.params['month'][0].to_i, @cgi.params['day'][0].to_i )
+		else
+			nil
+		end
+	end
+end
+
 #
 # make navigation buttons
 #
@@ -16,8 +36,10 @@ def navi
 	result << %Q[</div>]
 end
 
-def navi_item( link, label, rel = false )
-	%Q[<span class="adminmenu"><a href="#{link}"#{rel ? " rel=\"nofollow\"" : ''}>#{label}</a></span>\n]
+def navi_item( link, label, rel = nil )
+	result = %Q[<span class="adminmenu"><a href="#{link}"]
+	result << %Q[ rel="#{rel}"] if rel
+	result << %Q[>#{label}</a></span>\n]
 end
 
 def navi_user
@@ -48,17 +70,19 @@ end
 
 def navi_user_latest
 	result = ''
-	result << navi_item( "#{h @index}#{anchor( @conf['ndays.prev'] + '-' + @conf.latest_limit.to_s )}", "&laquo;#{navi_prev_ndays}" ) if @conf['ndays.prev'] and not bot?
+	result << navi_item( "#{h @index}#{anchor( @conf['ndays.prev'] + '-' + @conf.latest_limit.to_s )}", "&laquo;#{navi_prev_ndays}", "next" ) if @conf['ndays.prev'] and not bot?
 	result << navi_item( h(@index), h(navi_latest) ) if @cgi.params['date'][0]
-	result << navi_item( "#{h @index}#{anchor( @conf['ndays.next'] + '-' + @conf.latest_limit.to_s )}", "#{navi_next_ndays}&raquo;" ) if @conf['ndays.next'] and not bot?
+	result << navi_item( "#{h @index}#{anchor( @conf['ndays.next'] + '-' + @conf.latest_limit.to_s )}", "#{navi_next_ndays}&raquo;", "prev") if @conf['ndays.next'] and not bot?
 	result
 end
 
 def navi_user_day
 	result = ''
-	result << navi_item( "#{h @index}#{anchor @prev_day}", "&laquo;#{h navi_prev_diary(Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]))}" ) if @prev_day
-	result << navi_item( @index, navi_latest )
-	result << navi_item( "#{h @index}#{anchor @next_day}", "#{h navi_next_diary(Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]))}&raquo;" ) if @next_day
+	if @navi_user_days then
+		result << navi_item( "#{h @index}#{anchor @navi_user_days[0]}", "&laquo;#{h navi_prev_diary(navi_user_format(@navi_user_days[0]))}" ) if @navi_user_days[0]
+		result << navi_item( h(@index), h(navi_latest) )
+		result << navi_item( "#{h @index}#{anchor @navi_user_days[2]}", "#{h navi_next_diary(navi_user_format(@navi_user_days[2]))}&raquo;" ) if @navi_user_days[2]
+	end
 	result
 end
 
@@ -106,27 +130,30 @@ def navi_user_else
 	navi_item( h(@index), h(navi_latest) )
 end
 
+def navi_user_format( day )
+	Time::local( *day.scan( /^(\d{4})(\d\d)(\d\d)$/ )[0] )
+end
+
 def navi_admin
 	if @mode == 'day' then
-		result = navi_item( "#{h @update}?edit=true;year=#{@date.year};month=#{@date.month};day=#{@date.day}", h(navi_edit), true )
+		result = navi_item( "#{h @update}?edit=true;year=#{@date.year};month=#{@date.month};day=#{@date.day}", h(navi_edit), "nofollow" )
 	else
-		result = navi_item( h(@update), h(navi_update), true )
+		result = navi_item( h(@update), h(navi_update), "nofollow")
 	end
 	result << navi_item( "#{h @update}?conf=default", h(navi_preference) ) if /^(latest|month|day|comment|conf|nyear|category.*)$/ !~ @mode
 	result
 end
 
 def mobile_navi
-	calc_links
 	result = []
-	if @prev_day
-		result << %Q[<A HREF="#{h @index}#{anchor @prev_day}" ACCESSKEY="*">[*]#{mobile_navi_prev_diary}</A>]
+	if @navi_user_days and @navi_user_days[0]
+		result << %Q[<A HREF="#{h @index}#{anchor @navi_user_days[0]}" ACCESSKEY="*">[*]#{mobile_navi_prev_diary}</A>]
 	end
 	if @mode != 'latest'
 		result << %Q[<A HREF="#{h @index}" ACCESSKEY="0">[0]#{mobile_navi_latest}</A>]
 	end
-	if @next_day
-		result << %Q[<A HREF="#{h @index}#{anchor @next_day}" ACCESSKEY="#">[#]#{mobile_navi_next_diary}</A>]
+	if @navi_user_days and @navi_user_days[2]
+		result << %Q[<A HREF="#{h @index}#{anchor @navi_user_days[2]}" ACCESSKEY="#">[#]#{mobile_navi_next_diary}</A>]
 	end
 	if @mode == 'day' then
 		result << %Q[<A HREF="#{h @update}?edit=true;year=#{@date.year};month=#{@date.month};day=#{@date.day}" ACCESSKEY="5">[5]#{mobile_navi_edit}</A>]
@@ -187,7 +214,9 @@ add_header_proc do
 	#{mobile_link_discovery}
 	#{icon_tag}
 	#{description_tag}
+	#{jquery_tag.chomp}
 	#{css_tag.chomp}
+	#{iphone_tag.chomp}
 	#{title_tag.chomp}
 	#{robot_control.chomp}
 	HEADER
@@ -195,55 +224,31 @@ end
 
 def calc_links
 	if /day|edit/ =~ @mode or (@conf.mobile_agent? and /latest|month|nyear/ =~ @mode) then
-		years = []
-		@years.each do |k, v|
-			v.each do |m|
-				years << k + m
-			end
-		end
-		this_month = @date.strftime('%Y%m')
-		years |= [this_month]
-		years.sort!
-		years.unshift(nil).push(nil)
-		prev_month, dummy, next_month = years[years.index(this_month) - 1, 3]
-
+		today = @date.strftime('%Y%m%d')
 		days = []
-		if /(latest|month|nyear)/ === @mode
-			today = @diaries.keys.sort[-1]
-		else
-			today = @date.strftime('%Y%m%d')
+		yms = []
+		this_month = today[0,6]
+
+		@years.keys.each do |y|
+			yms += @years[y].collect {|m| y + m}
+		end
+		yms |= [this_month]
+		yms.sort!
+		yms.unshift(nil).push(nil)
+		yms[yms.index(this_month) - 1, 3].each do |ym|
+			next unless ym
+			now = @cgi.params['date'] # backup
+			cgi = @cgi.clone
+			cgi.params['date'] = [ym]
+			m = TDiaryMonthWithoutFilter.new(cgi, '', @conf)
+			@cgi.params['date'] = now # restore
+			m.diaries.delete_if {|date,diary| !diary.visible?}
+			days += m.diaries.keys.sort
 		end
-		days += @diaries.keys
 		days |= [today]
 		days.sort!
 		days.unshift(nil).push(nil)
-
-		current_date = @date.strftime( '%Y%m%d' )
-		days[0 .. days.index( today ) - 1].reverse_each do |d|
-		 	@prev_day = d
-			next if @mode == 'latest' and current_date == d
-			break unless @prev_day
-			break if (@mode == 'edit') or @diaries[@prev_day].visible?
-		end
-		if not @prev_day and prev_month then
-			y, m = prev_month.scan(/(\d{4})(\d\d)/)[0]
-			if m == "12"
-				y, m = y.to_i + 1, 1
-			else
-				y, m = y.to_i, m.to_i + 1
-			end
-			@prev_day = (Time.local(y, m, 1) - 24*60*60).strftime( '%Y%m%d' )
-		end
-
-		days[days.index( today ) + 1 .. -1].each do |d|
-			@next_day = d
-			break unless @next_day
-			break if (@mode == 'edit') or @diaries[@next_day].visible?
-		end
-		if not @next_day and next_month then
-			y, m = next_month.scan(/(\d{4})(\d\d)/)[0]
-			@next_day = Time.local(y, m, 1).strftime( '%Y%m%d' )
-		end
+		@navi_user_days = days[days.index(today) - 1, 3]
 	elsif @mode == 'nyear'
 		y = 2000 # specify leam year
 		m, d = @cgi.params['date'][0].scan(/^(\d\d)(\d\d)$/)[0]
@@ -344,6 +349,14 @@ def description_tag
 	end
 end
 
+def jquery_tag
+	if /^(form|edit|preview|showcomment|conf|saveconf)$/ =~ @mode then
+		%Q[<script src="http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.js" type="text/javascript"></script>\n\t<script src="js/00default.js" type="text/javascript"></script>]
+	else
+		''
+	end
+end
+
 def theme_url; 'theme'; end
 
 def css_tag
@@ -362,6 +375,21 @@ def css_tag
 	CSS
 end
 
+def iphone_tag
+	if @conf.iphone? then
+	<<-CSS
+<meta name = "viewport" content = "width = device-width">
+	<style type="text/css"><!--
+	form.comment textarea { 
+		width: 80%;
+	}
+	--></style>
+	CSS
+	else
+		''
+	end
+end
+
 def robot_control
 	if /^form|edit|preview|showcomment$/ =~ @mode then
 		'<meta name="robots" content="noindex,nofollow">'
@@ -458,9 +486,10 @@ def subtitle_link( date, index, subtitle )
 			r << "<a "
 			r << %Q[name="p#{'%02d' % index}" ] if @anchor_name
 			param = "#{date.strftime( '%Y%m%d' )}#p#{'%02d' % index}"
-			r << %Q[href="#{h @index}#{anchor param}">#{@conf.section_anchor}</a> ]
+			titleattr = (not subtitle or subtitle.empty?) ? '' : %Q[ title="#{remove_tag( subtitle ).gsub( /"/, "&quot;" )}"]
+			r << %Q[href="#{h @index}#{anchor param}"#{titleattr}>#{@conf.section_anchor}</a> ]
 		end
-	
+
 		r << %Q[(#{h @author}) ] if @multi_user and @author and subtitle
 	end
 	r << make_category_link( subtitle )
@@ -514,12 +543,17 @@ def comment_description
 end
 
 def comment_form_text
+	unless @diary then
+		@diary = @diaries[@date.strftime( '%Y%m%d' )]
+		return '' unless @diary
+	end
+
 	r = ''
 	unless @conf.hide_comment_form then
 		r = <<-FORM
 			<div class="form">
 		FORM
-		if @diaries[@date.strftime('%Y%m%d')].count_comments( true ) >= @conf.comment_limit_per_day then
+		if @diary.count_comments( true ) >= @conf.comment_limit_per_day then
 			r << <<-FORM
 				<div class="caption"><a name="c">#{comment_limit_label}</a></div>
 			FORM
@@ -529,7 +563,7 @@ def comment_form_text
 				<form class="comment" name="comment-form" method="post" action="#{h @index}"><div>
 				<input type="hidden" name="date" value="#{ @date.strftime( '%Y%m%d' )}">
 				<div class="field name">
-					#{comment_name_label}:<input class="field" name="name" value="#{h( @cgi.cookies['tdiary'][0] || '' )}">
+					#{comment_name_label}:<input class="field" name="name" value="#{h( @conf.to_native(@cgi.cookies['tdiary'][0] || '' ))}">
 				</div>
 				<div class="field mail">
 					#{comment_mail_label}:<input class="field" name="mail" value="#{h( @cgi.cookies['tdiary'][1] || '' )}">
@@ -557,7 +591,7 @@ add_footer_proc do
 		r = ''
 		r << <<-JS
 			<script type="text/javascript"><!--
-			document.getElementById('comment-form-section').innerHTML = '#{comment_form_text.gsub( /[\r\n]/, '' )}';
+			document.getElementById('comment-form-section').innerHTML = '#{comment_form_text.gsub( /[\r\n]/, '' ).gsub( /<\//, '<\\/' )}';
 			//--></script>
 		JS
 	else
@@ -638,7 +672,7 @@ def comment_mail_send
 	require 'socket'
 
 	name = comment_mail_mime( @conf.to_mail( @comment.name ) )[0]
-	body = @conf.to_mail( @comment.body.sub( /[\r\n]+\Z/, '' ) )
+	body = @comment.body.sub( /[\r\n]+\Z/, '' )
 	mail = @comment.mail
 	mail = @conf.author_mail unless mail =~ %r<[0-9a-zA-Z_.-]+@[\(\)%!0-9a-zA-Z_$@.&+-,'"*-]+>
 	mail = receivers[0] if mail.empty?
@@ -655,7 +689,7 @@ def comment_mail_send
 	mail_header = (@conf['comment_mail.header'] || '').dup
 	mail_header << ":#{@conf.date_format}" unless /%[a-zA-Z%]/ =~ mail_header
 	mail_header = @date.strftime( mail_header )
-	mail_header = comment_mail_mime( @conf.to_mail( mail_header ) ).join( "\n " ) if /[\x80-\xff]/ =~ mail_header
+	mail_header = comment_mail_mime( @conf.to_mail( mail_header ) ).join( "\n " ) #if /[\x80-\xff]/ =~ mail_header
 
 	rmail = ''
 	begin
@@ -663,7 +697,7 @@ def comment_mail_send
 	rescue
 		rmail = File::open( "#{::TDiary::PATH}/skel/mail.rtxt" ){|f| f.read }
 	end
-	text = ERB::new( rmail.untaint ).result( binding )
+	text = @conf.to_mail( ERB::new( rmail.untaint ).result( binding ) )
 	receivers.each { |i| i.untaint }
 	comment_mail( text, receivers )
 end
@@ -682,6 +716,19 @@ def comment_mail_basic_setting
 	end
 end
 
+#
+# convert to UTF-8
+#
+def to_utf8( str, charset = nil )
+	@conf.to_native( str, charset )
+end
+
+#
+# layout
+#
+def brr; '<br clear="right">'; end
+def brl; '<br clear="left">';  end
+
 #
 # preferences (saving methods)
 #
@@ -834,3 +881,67 @@ def saveconf_csrf_protection
 		nil
 	end
 end
+
+def saveconf_logger
+	if @mode == 'saveconf' then
+		@conf['log_level'] = @cgi.params['log_level'][0]
+	end
+end
+
+def conf_logger_list
+	log_level_list = ["DEBUG", "INFO", "WARN", "ERROR", "FATAL"]
+	r = ''
+
+	@conf['log_level'] ||= "INFO"
+
+	log_level_list.each do |level|
+		if level == @conf['log_level'] then
+			select = " selected"
+		end
+		r << %Q|<option value="#{h level}"#{select}>#{level}</option>|
+	end
+
+	r << %Q|</select></p>|
+end
+
+def saveconf_recommendfilter
+	if @mode == 'saveconf' && @cgi.params['recommend.filter'][0] == 'true' then
+		@conf['sf.selected'] = ""
+		@conf['comment_description'] = "ツッコミ・コメントがあればどうぞ! URIは1つまで入力可能です。"
+
+		if @sp_path.inject(false){|r, dir| r || FileTest.exist?("#{dir}/hide-mail-field.rb") }
+			if @conf['sp.selected']
+				@conf['sp.selected'].concat("hide-mail-field.rb\n")
+			else
+				@conf['sp.selected'] = "hide-mail-field.rb\n"
+			end
+			@conf['spamfilter.bad_mail_patts'] = "@"
+			@conf['comment_description'].concat("spam対策でE-mail欄は隠してあります。もしE-mail欄が見えていても、何も入力しないで下さい。")
+		end
+
+		@conf['spamfilter.bad_comment_patts'] = "href=\r\nurl=\r\nURL=\r\n"
+		@conf['spamfilter.bad_ip_addrs'] = ""
+		@conf['spamfilter.bad_uri_patts'] = ""
+		@conf['spamfilter.bad_uri_patts_for_mails'] = false
+		@conf['spamfilter.date_limit'] = "7"
+		@conf['spamfilter.debug_file'] = ""
+		@conf['spamfilter.debug_mode'] = false
+		@conf['spamfilter.filter_mode'] = false
+		@conf['spamfilter.hide_commentform'] = true
+		@conf['spamfilter.linkcheck'] = 1
+		@conf['spamfilter.max_rate'] = "0"
+		@conf['spamfilter.max_uris'] = "1"
+		@conf['spamfilter.resolv_check'] = true
+		@conf['spamfilter.resolv_check_mode'] = false
+		@conf['spamlookup.domain.list'] = "bsb.spamlookup.net\r\nsc.surbl.org\r\nrbl.bulkfeeds.jp"
+		@conf['spamlookup.ip.list'] = "dnsbl.spam-champuru.livedoor.com"
+		@conf['spamlookup.safe_domain.list'] = "www.google.com\r\nwww.google.co.jp\r\nezsch.ezweb.ne.jp\r\nwww.yahoo.co.jp\r\nsearch.mobile.yahoo.co.jp\r\nwww.bing.com"
+	end
+end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
