@@ -1,7 +1,8 @@
+# -*- coding: utf-8; -*-
 #
 # zh/00default.rb: Traditional-Chinese resources of 00default.rb.
 #
-# Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+# Copyright (C) 2001-2005, TADA Tadashi <t@tdtds.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
 
@@ -38,76 +39,68 @@ end
 # link to HOWTO write diary
 #
 def style_howto
-	%Q|/<a href="http://docs.tdiary.org/en/?#{h @conf.style}Style">g</a>|
-end
-
-#
-# convert to UTF-8
-#
-require 'iconv'
-def to_utf8( str, charset = 'Big5' )
-	Iconv::conv( 'UTF-8', charset, str )
+	%Q|/<a href="http://docs.tdiary.org/en/?#{h @conf.style}Style">撰寫指引</a>|
 end
 
 #
 # labels
 #
-def no_diary; "#{@date.strftime( @conf.date_format )} oѨSox"; end
-def comment_today; "jT"; end
-def comment_total( total ); "(`@: #{total} h)"; end
-def comment_new; 'ojT'; end
-def comment_description_default; 'woz糧媺jTAzg email }uxDHiHݨC'; end
+def no_diary; "#{@date.strftime( @conf.date_format )} 這天沒有發表日誌"; end
+def comment_today; "今日迴響"; end
+def comment_total( total ); "(總共有: #{total} 則)"; end
+def comment_new; '發表迴響'; end
+def comment_description_default; '歡迎發表您對本文的迴響，您填寫的 email 位址只有日誌主人可以看見。'; end
 def comment_limit_label; 'You cannot make more TSUKKOMI because it has over limit.'; end
-def comment_description_short; 'ojT!!'; end
-def comment_name_label; 'mW'; end
-def comment_name_label_short; 'mW'; end
-def comment_mail_label; 'qll'; end
-def comment_mail_label_short; 'l'; end
-def comment_body_label; 'jT'; end
-def comment_body_label_short; 'jT'; end
-def comment_submit_label; 'o'; end
-def comment_submit_label_short; 'o'; end
+def comment_description_short; '發表迴響!!'; end
+def comment_name_label; '姓名'; end
+def comment_name_label_short; '姓名'; end
+def comment_mail_label; '電子郵件'; end
+def comment_mail_label_short; '郵件'; end
+def comment_body_label; '迴響'; end
+def comment_body_label_short; '迴響'; end
+def comment_submit_label; '發表'; end
+def comment_submit_label_short; '發表'; end
 def comment_date( time ); time.strftime( "(#{@date_format} %H:%M)" ); end
-def trackback_today; "ޥ"; end
-def trackback_total( total ); "(`@: #{total} h)"; end
+def trackback_today; "今日引用"; end
+def trackback_total( total ); "(總共有: #{total} 則)"; end
 
-def navi_index; ''; end
-def navi_latest; '̷sx'; end
-def navi_oldest; '¤x'; end
-def navi_update; "sW"; end
-def navi_edit; "s"; end
-def navi_preference; "ﶵ]w"; end
-def navi_prev_diary(date); "e@hx (#{date.strftime(@date_format)})"; end
-def navi_next_diary(date); "U@hx (#{date.strftime(@date_format)})"; end
+def navi_index; '首頁'; end
+def navi_latest; '最新日誌'; end
+def navi_oldest; '最舊日誌'; end
+def navi_update; "新增"; end
+def navi_edit; "編輯"; end
+def navi_preference; "選項設定"; end
+def navi_prev_diary(date); "前一則日誌 (#{date.strftime(@date_format)})"; end
+def navi_next_diary(date); "下一則日誌 (#{date.strftime(@date_format)})"; end
 def navi_prev_month; "Prev month"; end
 def navi_next_month; "Next month"; end
-def navi_prev_nyear(date); "h~x (#{date.strftime('%m-%d')})"; end
-def navi_next_nyear(date); "~x (#{date.strftime('%m-%d')})"; end
+def navi_prev_nyear(date); "去年日誌 (#{date.strftime('%m-%d')})"; end
+def navi_next_nyear(date); "次年日誌 (#{date.strftime('%m-%d')})"; end
 def navi_prev_ndays; "#{@conf.latest_limit} days before"; end
 def navi_next_ndays; "#{@conf.latest_limit} days after"; end
 
 def submit_label
 	if @mode == 'form' or @cgi.valid?( 'appendpreview' ) then
-		'sW' #'Append'
+		'新增' #'Append'
 	else
-		'' #'Replace'
+		'替換' #'Replace'
 	end
 end
-def preview_label; 'w'; end #'Preview'
+def preview_label; '預覽'; end #'Preview'
 
-def nyear_diary_label(date, years); "鱡h"; end
-def nyear_diary_title(date, years); "Lhɦ"; end
+def nyear_diary_label(date, years); "往日情懷"; end
+def nyear_diary_title(date, years); "過去的此時此刻"; end
 
 
 #
 # labels (for mobile)
 #
-def mobile_navi_latest; '̷sx'; end
-def mobile_navi_update; "sW"; end
-def mobile_navi_edit; "s"; end
-def mobile_navi_preference; "ﶵ]w"; end
-def mobile_navi_prev_diary; "e@hx})"; end
-def mobile_navi_next_diary; "U@hx})"; end
+def mobile_navi_latest; '最新日誌'; end
+def mobile_navi_update; "新增"; end
+def mobile_navi_edit; "編輯"; end
+def mobile_navi_preference; "選項設定"; end
+def mobile_navi_prev_diary; "前一則日誌"; end
+def mobile_navi_next_diary; "下一則日誌"; end
 def mobile_label_hidden_diary; 'This day is HIDDEN.'; end
 
 #
@@ -120,7 +113,7 @@ def category_anchor(c); "[#{c}]"; end
 #
 
 # genre labels
-@conf_genre_label['basic'] = ''
+@conf_genre_label['basic'] = '基本'
 @conf_genre_label['theme'] = 'Themes'
 @conf_genre_label['tsukkomi'] = 'TSUKKOMI'
 @conf_genre_label['referer'] = 'Referrer'
@@ -128,26 +121,26 @@ def category_anchor(c); "[#{c}]"; end
 @conf_genre_label['etc'] = 'etc'
 
 # basic (default)
-add_conf_proc( 'default', '򥻳]w', 'basic' ) do
+add_conf_proc( 'default', '基本設定', 'basic' ) do
 	saveconf_default
 	@conf.description ||= ''
 	@conf.icon ||= ''
 	@conf.banner ||= ''
 	<<-HTML
-	<h3 class="subtitle">jD</h3>
-	#{"<p>oOzxjDAzJȷ|Φb HTML  &lt;title&gt; طCSO`NAФŨϥ HTML (tags)C </p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">大標題</h3>
+	#{"<p>這是您日誌的大標題，您填入的值會用在 HTML 的 &lt;title&gt; 項目當中。特別注意，本欄位請勿使用 HTML 標籤(tags)。 </p>" unless @conf.mobile_agent?}
 	<p><input name="html_title" value="#{h @conf.html_title}" size="50"></p>
 
-	<h3 class="subtitle">@</h3>
-	#{"<p>WzjWaI쪺ȱN|Φb HTML Y(header)̡C</p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">作者</h3>
+	#{"<p>填上您的大名吧！此欄位的值將會用在 HTML 標頭(header)裡。</p>" unless @conf.mobile_agent?}
 	<p><input name="author_name" value="#{h @conf.author_name}" size="40"></p>
 
-	<h3 class="subtitle">qll</h3>
-	#{"<p>Jzqll}A쪺ȱNΦb HTML Y(header)̡C</p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">電子郵件</h3>
+	#{"<p>填入您的電子郵件位址，此欄位的值將用在 HTML 標頭(header)裡。</p>" unless @conf.mobile_agent?}
 	<p><input name="author_mail" value="#{h @conf.author_mail}" size="40"></p>
 
-	<h3 class="subtitle">z޺() URL</h3>
-	#{"<p>Yzۤv}AiHbUC</p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">您索引網頁(首頁)的 URL</h3>
+	#{"<p>若您有自己的網站位址，可以填註在下面。</p>" unless @conf.mobile_agent?}
 	<p><input name="index_page" value="#{h @conf.index_page}" size="50"></p>
 
 	<h3 class="subtitle">URL of Your Diary</h3>
@@ -170,65 +163,65 @@ add_conf_proc( 'default', '򥻳]w', 'basic' ) do
 end
 
 # header/footer (header)
-add_conf_proc( 'header', 'ܻP}', 'basic' ) do
+add_conf_proc( 'header', '頁眉與頁腳', 'basic' ) do
 	saveconf_header
 
 	<<-HTML
-	<h3 class="subtitle"></h3>
-	#{"<p>oqrN|\mbCӭݡAziHϥ HTML ykCOФŲ \"&lt;%=navi%&gt;\"ҡA]N]t\"s\"(Update)\\sbuCvA \"&lt;%=calendar%&gt;\" ҥNCBz]iHۥѷft䥦 pluginC </p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">頁眉</h3>
+	#{"<p>這段文字將會擺置在每個頁面的頂端，您可以使用 HTML 語法。但是請勿移除 \"&lt;%=navi%&gt;\"標籤，因為它代表包含\"更新\"(Update)功\能鈕在內的「導覽列」，而 \"&lt;%=calendar%&gt;\" 標籤代表日曆。此處您也可以自由搭配其它的 plugin。 </p>" unless @conf.mobile_agent?}
 	<p><textarea name="header" cols="70" rows="10">#{h @conf.header}</textarea></p>
-	<h3 class="subtitle">}</h3>
-	#{"<p>oqrFmOm󩳺ݥH~AlpPܡC </p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">頁腳</h3>
+	#{"<p>這段文字除了它的位置是置於底端以外，其餘都如同頁眉。 </p>" unless @conf.mobile_agent?}
 	<p><textarea name="footer" cols="70" rows="10">#{h @conf.footer}</textarea></p>
 	HTML
 end
 
 # diaplay
-add_conf_proc( 'display', '', 'basic' ) do
+add_conf_proc( 'display', '顯示', 'basic' ) do
 	saveconf_display
 
 	<<-HTML
-	<h3 class="subtitle">qI(anchor)NO</h3>
-	#{"<p>\"I\" Nqb䥦iHPzx۳sCqI|QmCӬq}YBAziHw \"&lt;span class=\"sanchor\"&gt;_&lt;/span&gt;\"AӹϧΤILA|ѧGDD]pӨMwC </p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">段落的錨點(anchor)代表記號</h3>
+	#{"<p>\"錨點\" 的意義在於讓其它網站可以與您的日誌互相連結。段落錨點會被置於每個段落的開頭處，您可以指定 \"&lt;span class=\"sanchor\"&gt;_&lt;/span&gt;\"，而圖形化錨點的有無，會由佈景主題的設計來決定。 </p>" unless @conf.mobile_agent?}
 	<p><input name="section_anchor" value="#{h @conf.section_anchor}" size="40"></p>
-	<h3 class="subtitle">jTI(anchor)NO</h3>
-	#{"<p>jTI|mChjT}YBAziHw \"&lt;span class=\"canchor\"&gt;_&lt;/span&gt;\"C</p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">迴響的錨點(anchor)代表記號</h3>
+	#{"<p>迴響的錨點會置於每則迴響的開頭處，您可以指定 \"&lt;span class=\"canchor\"&gt;_&lt;/span&gt;\"。</p>" unless @conf.mobile_agent?}
 	<p><input name="comment_anchor" value="#{h @conf.comment_anchor}" size="40"></p>
-	<h3 class="subtitle">榡</h3>
-	#{"<p>榡A@zwUCo % ŸftrAզXNiN榡Ap \"%Y\"(~), \"%m\"()\"%b\"(²uܪk), \"%B\"(ܪk), \"%d\"(), \"%a\"(P²uܪk), \"%A\"(Pܪk)C</p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">日期的格式</h3>
+	#{"<p>日期的格式，一旦您指定下列這些 % 符號之後搭配的字元，其組合就可代表日期格式，如 \"%Y\"(年), \"%m\"(月)﹜\"%b\"(月份的簡短表示法), \"%B\"(月份的長表示法), \"%d\"(日), \"%a\"(星期的簡短表示法), \"%A\"(星期的長表示法)。</p>" unless @conf.mobile_agent?}
 	<p><input name="date_format" value="#{h @conf.date_format}" size="30"></p>
-	<h3 class="subtitle">u̷sxv̦hnqXXѥH</h3>
-	#{"<p>bu̷sxvAznܦh֤ѥxH </p>" unless @conf.mobile_agent?}
-	<p><input name="latest_limit" value="#{h @conf.latest_limit}" size="2"> ѥ</p>
-	<h3 class="subtitle">鱡h</h3>
-	#{"<p>O_nqX \"鱡h\" (PP骺Lhx)H</p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">「最新日誌」最多要秀出幾天份？</h3>
+	#{"<p>在「最新日誌」當中，您要顯示多少天份的日誌？ </p>" unless @conf.mobile_agent?}
+	<p><input name="latest_limit" value="#{h @conf.latest_limit}" size="2"> 天份</p>
+	<h3 class="subtitle">往日情懷</h3>
+	#{"<p>是否要秀出 \"往日情懷\" (同月同日的過去日誌)？</p>" unless @conf.mobile_agent?}
 	<p><select name="show_nyear">
-		<option value="true"#{" selected" if @conf.show_nyear}>qI</option>
-		<option value="false"#{" selected" unless @conf.show_nyear}></option>
+		<option value="true"#{" selected" if @conf.show_nyear}>秀！</option>
+		<option value="false"#{" selected" unless @conf.show_nyear}>隱藏</option>
 	</select></p>
 	HTML
 end
 
 # timezone
-add_conf_proc( 'timezone', 'ɶtվ', 'update' ) do
+add_conf_proc( 'timezone', '時間差的調整', 'update' ) do
 	saveconf_timezone
 	<<-HTML
-	<h3 class="subtitle">ɶtվ</h3>
-	#{"<p>YOzsFxAziHzL(쬰p)Ӱ۰ʽվɶtCҦpAzYQnwbMIҵoxQOQѪxAzNiHbo̶J -2CtDiary |ѦҦƭȨӧPwogxoC </p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">時間差的調整</h3>
+	#{"<p>若是您更新了日誌，您可以透過此欄位(單位為小時)來做自動調整時間差。例如說，您若想要指定在清晨兩點所發表的日誌被當成是昨天的日誌，您就可以在這裡填入 -2。tDiary 會參考此數值來判定這篇日誌的發表日期。 </p>" unless @conf.mobile_agent?}
 	<p><input name="hour_offset" value="#{h @conf.hour_offset}" size="5"></p>
 	HTML
 end
 
 # themes
-@theme_location_comment = "<p>ziHb <a href=\"http://www.tdiary.org/20021001.html\">Theme Gallery</a>(饻y) ohGDDI</p>"
+@theme_location_comment = "<p>您可以在 <a href=\"http://www.tdiary.org/20021001.html\">Theme Gallery</a>(日本語) 取得更多的佈景主題！</p>"
 @theme_thumbnail_label = "Thumbnail"
 
-add_conf_proc( 'theme', 'GDD', 'theme' ) do
+add_conf_proc( 'theme', '佈景主題', 'theme' ) do
 	saveconf_theme
 
 	 r = <<-HTML
-	<h3 class="subtitle">GDD</h3>
-	#{"<p>ܱzxQnGDDμ˦(CSS)ApGzܤF \"CSS specify\"AЦbk(U)̿J CSS Ҧb}C </p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">佈景主題</h3>
+	#{"<p>選擇您日誌想要的佈景主題或樣式表(CSS)，如果您選擇了 \"CSS specify\"，請在右(下)方欄位裡輸入 CSS 所在的網址。 </p>" unless @conf.mobile_agent?}
 	<p>
 	<select name="theme" onChange="changeTheme( theme_thumbnail, this )">
 		<option value="">CSS Specify-&gt;</option>
@@ -237,19 +230,19 @@ add_conf_proc( 'theme', 'GDD', 'theme' ) do
 end
 
 # comments
-add_conf_proc( 'comment', 'jT', 'tsukkomi' ) do
+add_conf_proc( 'comment', '迴響', 'tsukkomi' ) do
 	saveconf_comment
 
 	<<-HTML
-	<h3 class="subtitle">O_nqXjTH</h3>
-	#{"<p>nnqXṶ̵̄zjTH </p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">是否要秀出迴響？</h3>
+	#{"<p>要不要秀出讀者們給您的迴響？ </p>" unless @conf.mobile_agent?}
 	<p><select name="show_comment">
-		<option value="true"#{" selected" if @conf.show_comment}>n</option>
-		<option value="false"#{" selected" unless @conf.show_comment}>n</option>
+		<option value="true"#{" selected" if @conf.show_comment}>好</option>
+		<option value="false"#{" selected" unless @conf.show_comment}>不要</option>
 	</select></p>
-	<h3 class="subtitle">nqXXgjTH</h3>
-	#{"<p>bu̷sxvΡuYxvҥܤUAzQnqXhֽgijTH ۹ӻAbugvҥܤUAҦjT|qXӡC </p>" unless @conf.mobile_agent?}
-	<p>qX <input name="comment_limit" value="#{h @conf.comment_limit}" size="3"> gjT</p>
+	<h3 class="subtitle">要秀出幾篇迴響？</h3>
+	#{"<p>在「最新日誌」或「某月日誌」模示下，您想要秀出多少篇可見的迴響？ 相對來說，在「單篇」模示下，所有的迴響都會秀出來。 </p>" unless @conf.mobile_agent?}
+	<p>秀出 <input name="comment_limit" value="#{h @conf.comment_limit}" size="3"> 篇迴響</p>
 	<h3 class="subtitle">Limit of TSUKKOMI per a day</h3>
 	#{"<p>When numbers of TSUKKOMI over this value in a day, nobody can make new TSUKKOMI. If you use TrackBack plugin, this value means sum of TSUKKOMIs and TrackBacks.</p>" unless @conf.mobile_agent?}
 	<p><input name="comment_limit_per_day" value="#{h @conf.comment_limit_per_day}" size="3"> TSUKKOMIs</p>
@@ -262,7 +255,7 @@ def comment_mail_mime( str )
 	[str.dup]
 end
 
-def comment_mail_conf_label; 'HHqzjT'; end
+def comment_mail_conf_label; '以信件通知您有迴響'; end
 
 def comment_mail_basic_html
 	@conf['comment_mail.header'] = '' unless @conf['comment_mail.header']
@@ -270,17 +263,17 @@ def comment_mail_basic_html
 	@conf['comment_mail.sendhidden'] = false unless @conf['comment_mail.sendhidden']
 
 	<<-HTML
-	<h3 class="subtitle">O_QΫHqjTH</h3>
-	#{"<p>пܦbsjTɭnnHqllqzCаOoo\\ݭnzb tdiary.conf ]w SMTP AC</p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">是否利用信件通知有迴響？</h3>
+	#{"<p>請選擇在有新的迴響時要不要以電子郵件通知您。請記得這項功\能需要您在 tdiary.conf 設定 SMTP 伺服器。</p>" unless @conf.mobile_agent?}
 	<p><select name="comment_mail.enable">
-		<option value="true"#{" selected" if @conf['comment_mail.enable']}>Хζlq</option>
-        <option value="false"#{" selected" unless @conf['comment_mail.enable']}>ΤF</option>
+		<option value="true"#{" selected" if @conf['comment_mail.enable']}>請用郵件通知</option>
+        <option value="false"#{" selected" unless @conf['comment_mail.enable']}>不用了</option>
 	</select></p>
-	<h3 class="subtitle">}</h3>
-	#{"<p>ЫwnjTqqll}A@g@Ӧ}CpGǫSt~wAhqHN|Hzqll}C</p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">收件位址</h3>
+	#{"<p>請指定要收到迴響通知的電子郵件位址，一行寫一個位址。如果這裡沒有另外指定，則通知信將會寄到您的電子郵件位址。</p>" unless @conf.mobile_agent?}
 	<p><textarea name="comment_mail.receivers" cols="40" rows="3">#{h @conf['comment_mail.receivers'].gsub( /[, ]+/, "\n")}</textarea></p>
-	<h3 class="subtitle">HD</h3>
-	#{"<p>w@ӷ|\bqHuHDv}YBrCHD|O \"zwr:DATE-SERIAL NAME\" ˦C \"date\" OzxoAOpGztwF˦ADh|ܬ \"zwr-SERIAL NAME\" (ex: \"hoge:%Y-%m-%d\")</p>" unless @conf.mobile_agent?}
+	<h3 class="subtitle">信件標題</h3>
+	#{"<p>指定一個會擺在通知信的「信件標題」開頭處的字串。信件標題會是 \"您指定的字串:DATE-SERIAL NAME\" 的樣式。 \"date\" 是您日誌發表的日期，但是如果您另行指定了日期的樣式，標題則會變為 \"您指定的字串-SERIAL NAME\" (ex: \"hoge:%Y-%m-%d\")</p>" unless @conf.mobile_agent?}
 	<p><input name="comment_mail.header" value="#{h @conf['comment_mail.header']}"></p>
 	<h3 class="subtitle">About hidden TSUKKOMI</h3>
 	#{"<p>Some TSUKKOMI are hidden by filters. You can decide which sending E-mail by hidden TSUKKOMI.</p>" unless @conf.mobile_agent?}
@@ -314,28 +307,28 @@ add_conf_proc( 'csrf_protection', 'CSRF Protection', 'security' ) do
             <input type="hidden" name="check_enabled" value="true">'
           else
             '<input type="checkbox" name="check_enabled" value="true">'
-        end}Enabled (default)</input>
+        end}Enabled (default)
 	</p>
 	#{"<p>Configures Referer-based CSRF protection.
 	TDiary checks the Referer value sent from your web browser. If the post request comes from some outer page,
 	the request will be rejected. This setting can't be disabled through web-based configuration, for safety reasons.</p>
 	" unless @conf.mobile_agent?}
 	<h3 class="subtitle">Handling of Referer-disabled browsers</h3>
-	<p><input type="radio" name="check_referer" value="true" #{if [1,3].include?(csrf_protection_method) then " checked" end}>Reject (default)</input>
-	<input type="radio" name="check_referer" value="false" #{if [0,2].include?(csrf_protection_method) then " checked" end}>Accept</input>
+	<p><input type="radio" name="check_referer" value="true" #{if [1,3].include?(csrf_protection_method) then " checked" end}>Reject (default)
+	<input type="radio" name="check_referer" value="false" #{if [0,2].include?(csrf_protection_method) then " checked" end}>Accept
 	</p>
 	#{"<p>Configures handling for requests without any Referer: value.
 	By default tDiary rejects such request for safety reasons.
 	If your browser is configured not to send Referer values, alter that setting to allow sending Referer, at least for
-	originating sites. If it is impossible, configure the key-based CSRF protection below, and 
+	originating sites. If it is impossible, configure the key-based CSRF protection below, and
 	change this setting to \"Accept\".</p>
 	" unless @conf.mobile_agent?}
 	</div>
 	<div class="section">
 	<h3 class="subtitle">Checking CSRF key</h3>
 	<h4>Checks for CSRF protection key</h4>
-	<p><input type="radio" name="check_key" value="true" #{if [2,3].include?(csrf_protection_method) then " checked" end}>Enabled</input>
-	<input type="radio" name="check_key" value="false" #{if [0,1].include?(csrf_protection_method) then " checked" end}>Disabled (default)</input>
+	<p><input type="radio" name="check_key" value="true" #{if [2,3].include?(csrf_protection_method) then " checked" end}>Enabled
+	<input type="radio" name="check_key" value="false" #{if [0,1].include?(csrf_protection_method) then " checked" end}>Disabled (default)
 	</p>
 	#{"<p>TDiary can add a secret key for every post form to prevent CSRF. As long as attackers do not know the secret key,
 	forged requests will not be granted. To enable this feature, you must specify the secret key below.
@@ -345,7 +338,7 @@ add_conf_proc( 'csrf_protection', 'CSRF Protection', 'security' ) do
 	#{"<p>A secret key used for key-based CSRF protection. Specify a secret string which is not easy to guess.
 	If this key is leaked, CSRF attacks can be exploited.
 	Do not use any passwords used in other places. You need not to remember this phrase to type in.</p>" unless @conf.mobile_agent?}
-	#{"<p class=\"message\">Caution: 
+	#{"<p class=\"message\">Caution:
 	Your browser seems not to be sending any Referers, although Referer-based protection is enabled.
 	<a href=\"#{h @update}?conf=csrf_protection\">Please open this page again via this link</a>.
 	If you see this message again, you must either change your browser setting (temporarily to change these settings, at least),
@@ -353,3 +346,34 @@ add_conf_proc( 'csrf_protection', 'CSRF Protection', 'security' ) do
 	</div>
 	HTML
 end
+
+add_conf_proc( 'logger', 'Log Level', 'basic' ) do
+	saveconf_logger
+
+	r = <<-HTML
+	<h3 class="subtitle">Log Level</h3>
+	<p>Select log level of tDiary's output. If you selected spam filter's log level is enabled then select INFO or DEBUG.</p>
+	<p><select name="log_level">
+	HTML
+	r << conf_logger_list
+end
+
+add_conf_proc( 'suggestfilter', 'Recommend filter', 'basic' ) do
+	saveconf_recommendfilter
+
+	<<-HTML
+	<h3>Recommend filter</h3>
+	<p>Spam filtering for tDiary recommended to change the settings. Now, caution that all change what is settings.</p>
+	<p>
+		<input type="checkbox" id="recommend.filter" name="recommend.filter" value="true">
+		<label for="recommend.filter">Enabled recommend filter</label>
+	</p>
+	HTML
+end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
