@@ -1,15 +1,15 @@
+# -*- coding: utf-8; -*-
 =begin
 == NAME
 tDiary: the "tsukkomi-able" web diary system.
-tdiary.rb $Revision: 1.339 $
 
-Copyright (C) 2001-2007, TADA Tadashi <sho@spc.gr.jp>
+Copyright (C) 2001-2010, TADA Tadashi <t@tdtds.jp>
 You can redistribute it and/or modify it under GPL2.
 =end
 
-TDIARY_VERSION = '2.2.1'
+TDIARY_VERSION = '3.0.1'
 
-$:.insert( 1, File::dirname( __FILE__ ) + '/misc/lib' )
+$:.insert( 1, File::dirname( __FILE__ ).untaint + '/misc/lib' )
 
 require 'cgi'
 require 'uri'
@@ -18,6 +18,7 @@ begin
 rescue LoadError
 	require 'erb'
 end
+require 'compatible'
 
 =begin
 == String class
@@ -56,7 +57,11 @@ class CGI
 	end
 
 	def mobile_agent?
-		self.user_agent =~ %r[(DoCoMo|J-PHONE|Vodafone|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode|WILLCOM|SoftBank)]i
+		self.user_agent =~ %r[(DoCoMo|J-PHONE|Vodafone|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode|WILLCOM|SoftBank|Semulator|Vemulator|J-EMULATOR|emobile|mixi-mobile-converter)]i
+	end
+
+	def smartphone?
+		self.user_agent =~ /iPhone|iPod|Opera Mini|Android.*Mobile|NetFront|PSP/
 	end
 
 	def https?
@@ -110,15 +115,15 @@ module Safe
 			result = yield
 		end
 		result
-  end
-  module_function :safe
+	end
+	module_function :safe
 end
 
 #
 # module TDiary
 #
 module TDiary
-	PATH = File::dirname( __FILE__ )
+	PATH = File::dirname( __FILE__ ).untaint
 
 	#
 	# class Comment
@@ -133,7 +138,7 @@ module TDiary
 		end
 
 		def shorten( length = 120 )
-			matched = body.gsub( /\n/, ' ' ).scan( /^.{0,#{length - 2}}/ )[0]
+			matched = body.gsub( /\n/, ' ' ).scan( /^.{0,#{length - 2}}/u )[0]
 			unless $'.empty? then
 				matched + '..'
 			else
@@ -273,7 +278,11 @@ module TDiary
 
 		def each_referer( limit = 10 )
 			newer_referer
-			@referers.values.sort.reverse.each_with_index do |ary,idx|
+			# dirty workaround to avoid recursive sort that
+			# causes SecurityError in @secure=true
+			# environment since
+			# http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=16081
+			@referers.values.sort_by{|e| "%08d_%s" % e}.reverse.each_with_index do |ary,idx|
 				break if idx >= limit
 				yield ary[0], ary[1]
 			end
@@ -303,20 +312,14 @@ module TDiary
 			DEBUG_SPAM = 1
 			DEBUG_FULL = 2
 
-			def initialize( cgi, conf )
-				@cgi, @conf = cgi, conf
+			def initialize( cgi, conf, logger )
+				@cgi, @conf, @logger = cgi, conf, logger
 
 				if @conf.options.include?('filter.debug_mode')
 					@debug_mode = @conf.options['filter.debug_mode']
 				else
 					@debug_mode = DEBUG_NONE
 				end
-
-				if @conf.options.include?('filter.debug_file')
-					@debug_file = @conf.options['filter.debug_file']
-				else
-					@debug_file = nil
-				end
 			end
 
 			def comment_filter( diary, comment )
@@ -331,11 +334,7 @@ module TDiary
 				return if @debug_mode == DEBUG_NONE
 				return if @debug_mode == DEBUG_SPAM and level == DEBUG_FULL
 
-				require 'time'
-				File.open( @debug_file, 'a' ) do |io|
-					io.flock(File::LOCK_EX)
-					io.puts "#{Time.now.iso8601}: #{@cgi.remote_addr}->#{(@cgi.params['date'][0] || 'no date').dump}: #{msg}"
-				end
+				@logger.info("#{@cgi.remote_addr}->#{(@cgi.params['date'][0] || 'no date').dump}: #{msg}")
 			end
 		end
 	end
@@ -406,6 +405,7 @@ module TDiary
 	class PermissionError < TDiaryError; end
 	class PluginError < TDiaryError; end
 	class BadStyleError < TDiaryError; end
+	class NotFound < TDiaryError;	end
 
 	#
 	# class IOBase
@@ -425,11 +425,7 @@ module TDiary
 		end
 
 		def styled_diary_factory( date, title, body, style_name = 'tDiary' )
-			if style_class = style( style_name.downcase )
-				return style_class::new( date, title, body )
-			else
-				raise BadStyleError, "bad style: #{style_name}"
-			end
+			return style( style_name.downcase )::new( date, title, body )
 		end
 
 		def load_styles
@@ -442,7 +438,14 @@ module TDiary
 		end
 
 		def style( s )
-			@styles ? @styles[s.downcase] : nil
+			unless @styles
+				raise BadStyleError, "styles are not loaded"
+			end
+			r = @styles[s.downcase]
+			unless r
+				raise BadStyleError, "bad style: #{s}"
+			end
+			return r
 		end
 	end
 
@@ -466,7 +469,7 @@ module TDiary
 			load
 
 			instance_variables.each do |v|
-				v.sub!( /@/, '' )
+				v = v.to_s.sub( /@/, '' )
 				instance_eval( <<-SRC
 					def #{v}
 						@#{v}
@@ -487,7 +490,7 @@ module TDiary
 		def save
 			result = ERB::new( File::open( "#{PATH}/skel/tdiary.rconf" ){|f| f.read }.untaint ).result( binding )
 			result.untaint unless @secure
-			Safe::safe( @secure ? 4 : 1 ) do
+			Safe::safe( @secure ? 4 : TDIARY_SAFE_NORMAL ) do
 				eval( result, binding, "(TDiary::Config#save)", 1 )
 			end
 			File::open( "#{@data_path}tdiary.conf", 'w' ) do |o|
@@ -499,6 +502,11 @@ module TDiary
 			@cgi.mobile_agent?
 		end
 
+		def smartphone?
+			@cgi.smartphone?
+		end
+		alias iphone? smartphone?
+
 		def bot?
 			@bot =~ @cgi.user_agent
 		end
@@ -531,13 +539,17 @@ module TDiary
 
 		def base_url_auto
 			return '' unless @cgi.script_name
-			if @cgi.https?
-				port = (@cgi.server_port == 443) ? '' : ':' + @cgi.server_port.to_s
-				"https://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
-			else
-				port = (@cgi.server_port == 80) ? '' : ':' + @cgi.server_port.to_s
-				"http://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
-			end.sub(%r|/+$|, '/')
+			begin
+				if @cgi.https?
+					port = (@cgi.server_port == 443) ? '' : ':' + @cgi.server_port.to_s
+					"https://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
+				else
+					port = (@cgi.server_port == 80) ? '' : ':' + @cgi.server_port.to_s
+					"http://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
+				end.sub(%r|/+$|, '/')
+			rescue SecurityError
+				''
+			end
 		end
 
 	private
@@ -615,27 +627,47 @@ module TDiary
 			@data_path += '/' if /\/$/ !~ @data_path
 			raise TDiaryError, 'Do not set @data_path as same as tDiary system directory.' if @data_path == "#{PATH}/"
 
-			variables = [
-				:html_title, :author_name, :author_mail, :index_page, :hour_offset,
-				:description, :icon, :banner,
-				:header, :footer,
-				:section_anchor, :comment_anchor, :date_format, :latest_limit, :show_nyear,
-				:theme, :css,
-				:show_comment, :comment_limit, :comment_limit_per_day,
-				:mail_on_comment, :mail_header,
-				:show_referer, :no_referer2, :only_volatile2, :referer_table2,
-				:options2,
-			]
 			begin
+				def_vars1 = ''
+				def_vars2 = ''
+				[
+					:tdiary_version,
+					:html_title, :author_name, :author_mail, :index_page, :hour_offset,
+					:description, :icon, :banner,
+					:header, :footer,
+					:section_anchor, :comment_anchor, :date_format, :latest_limit, :show_nyear,
+					:theme, :css,
+					:show_comment, :comment_limit, :comment_limit_per_day,
+					:mail_on_comment, :mail_header,
+					:show_referer, :no_referer2, :only_volatile2, :referer_table2,
+					:options2,
+				].each do |var|
+					def_vars1 << "#{var} = nil\n"
+					def_vars2 << "@#{var} = #{var} unless #{var} == nil\n"
+				end
+
 				cgi_conf = File::open( "#{@data_path}tdiary.conf" ){|f| f.read }
 				cgi_conf.untaint unless @secure
-				def_vars = ""
-				variables.each do |var| def_vars << "#{var} = nil\n" end
-				eval( def_vars )
-				Safe::safe( @secure ? 4 : 1 ) do
-					eval( cgi_conf, binding, "(TDiary::Config#cgi_conf)", 1 )
+
+				b = binding.taint
+				eval( def_vars1, b )
+				Safe::safe( @secure ? 4 : TDIARY_SAFE_NORMAL ) do
+					begin
+						eval( cgi_conf, b, "(TDiary::Config#load_cgi_conf)", 1 )
+					rescue SyntaxError
+						enc = case @lang
+							when 'en'
+								'UTF-8'
+							when 'zh'
+								'Big5'
+							else
+								'EUC-JP'
+							end
+						cgi_conf.force_encoding( enc )
+						retry
+					end
 				end
-				variables.each do |var| eval "@#{var} = #{var} if #{var} != nil" end
+				eval( def_vars2, b )
 			rescue IOError, Errno::ENOENT
 			end
 		end
@@ -663,6 +695,7 @@ module TDiary
 	class Plugin
 		include ERB::Util
 		attr_reader :cookies
+		attr_writer :comment, :date, :diaries, :last_modified
 
 		def initialize( params )
 			@header_procs = []
@@ -682,8 +715,8 @@ module TDiary
 			@conf_genre_label = {}
 			@cookies = []
 
-			params.each_key do |key|
-				eval( "@#{key} = params['#{key}']" )
+			params.each do |key, value|
+				instance_variable_set( "@#{key}", value )
 			end
 
 			# for 1.4 compatibility
@@ -716,6 +749,8 @@ module TDiary
 					load_plugin( file )
 					@plugin_files << plugin_file
 				end
+			rescue ::TDiary::ForceRedirect
+				raise
 			rescue Exception
 				raise PluginError::new( "Plugin error in '#{File::basename( plugin_file )}'.\n#{$!}\n#{$!.backtrace[0]}" )
 			end
@@ -746,7 +781,7 @@ module TDiary
 			@section_enter_procs.taint
 			@subtitle_procs.taint
 			@section_leave_procs.taint
-			return Safe::safe( secure ? 4 : 1 ) do
+			return Safe::safe( secure ? 4 : TDIARY_SAFE_NORMAL ) do
 				eval( src, binding, "(TDiary::Plugin#eval_src)", 1 )
 			end
 		end
@@ -951,7 +986,7 @@ module TDiary
 			r = str.dup
 			if @options['apply_plugin'] and str.index( '<%' ) then
 				r = str.untaint if $SAFE < 3
-				Safe::safe( @conf.secure ? 4 : 1 ) do
+				Safe::safe( @conf.secure ? 4 : TDIARY_SAFE_NORMAL ) do
 					begin
 						r = ERB::new( r ).result( binding )
 					rescue Exception
@@ -967,8 +1002,8 @@ module TDiary
 			ref = @conf.to_native( CGI::unescape( ref ) )
 			str = nil
 			table.each do |url, name|
-				if /#{url}/i =~ ref then
-					str = ref.gsub( /#{url}/in, name )
+				if /#{url}/iu =~ ref then
+					str = ref.gsub( /#{url}/iu, name )
 					break
 				end
 			end
@@ -1030,6 +1065,9 @@ module TDiary
 				@conf.io_class = DefaultIO
 			end
 			@io = @conf.io_class.new( self )
+
+			# load logger
+			load_logger
 		end
 
 		def eval_rhtml( prefix = '' )
@@ -1086,7 +1124,12 @@ module TDiary
 						File::open( path ) {|f| f.read }
 					end
 				}.join
-				r = ERB::new( rhtml.untaint ).result( binding )
+				begin
+					r = ERB::new( rhtml.untaint ).result( binding )
+				rescue Encoding::CompatibilityError
+					# migration error on ruby 1.9 only 1st time, reload.
+					raise ForceRedirect::new( @conf.base_url )
+				end
 				r = ERB::new( r ).src
 				store_cache( r, prefix ) unless @diaries.empty?
 			end
@@ -1112,7 +1155,8 @@ module TDiary
 				'cache_path' => cache_path,
 				'date' => @date,
 				'comment' => @comment,
-				'last_modified' => last_modified
+				'last_modified' => last_modified,
+				'logger' => @logger
 			)
 		end
 
@@ -1214,13 +1258,17 @@ module TDiary
 			filter_path = @conf.filter_path || "#{PATH}/tdiary/filter"
 			Dir::glob( "#{filter_path}/*.rb" ).sort.each do |file|
 				require file.untaint
-				@filters << TDiary::Filter::const_get( "#{File::basename( file, '.rb' ).capitalize}Filter" )::new( @cgi, @conf )
+				@filters << TDiary::Filter::const_get( "#{File::basename( file, '.rb' ).capitalize}Filter" )::new( @cgi, @conf, @logger )
 			end
 		end
 
+		def all_filters
+			load_filters
+			@filters + (load_plugins.sf_filters || [])
+		end
+
 		def comment_filter( diary, comment )
-			load_filters unless @filters
-			@filters.each do |filter|
+			all_filters.each do |filter|
 				return false unless filter.comment_filter( diary, comment )
 				break unless comment.visible?
 			end
@@ -1228,12 +1276,38 @@ module TDiary
 		end
 
 		def referer_filter( referer )
-			load_filters unless @filters
-			@filters.each do |filter|
+			all_filters.each do |filter|
 				return false unless filter.referer_filter( referer )
 			end
 			true
 		end
+
+		def load_logger
+			return if @logger
+
+			require 'fileutils'
+			require 'logger'
+
+			# create log directory
+			log_path = @conf.options['log_path'] || "#{@conf.data_path}/log/"
+			FileUtils::mkdir_p( log_path ) unless FileTest::directory?( log_path ) 
+
+			log_file = log_path + "debug.log"
+			@logger = Logger::new( log_file, 'daily' )
+
+			case @conf.options['log_level']
+			when "FATAL"
+				@logger.level = Logger::FATAL
+			when "ERROR"
+				@logger.level = Logger::ERROR
+			when "WARN"
+				@logger.level = Logger::WARN
+			when "INFO"
+				@logger.level = Logger::INFO
+			else
+				@logger.level = Logger::DEBUG
+			end
+		end
 	end
 
 	#
@@ -1639,6 +1713,7 @@ EOS
 					end
 					dirty
 				end
+				@date = @diary.date if @diary
 			end
 		end
 
@@ -1700,7 +1775,8 @@ EOS
 			super
 			begin
 				# time is noon for easy to calc leap second.
-				load( Time::local( *@cgi.params['date'][0].scan( /^(\d{4})(\d\d)(\d\d)$/ )[0] ) + 12*60*60 )
+				@date = Time::local( *@cgi.params['date'][0].scan( /^(\d{4})(\d\d)(\d\d)$/ )[0] ) + 12*60*60
+				load( @date )
 			rescue ArgumentError, NameError
 				raise TDiaryError, 'bad date'
 			end
@@ -1711,14 +1787,21 @@ EOS
 			@diary ? @diary.last_modified : Time::at( 0 )
 		end
 
+		def eval_rhtml( prefix = '' )
+			if not @diary and @conf.bot?
+				raise NotFound
+			else
+				super(prefix)
+			end
+		end
+
 	protected
 		def load( date )
 			if not @diary or (@diary.date.dup + 12*60*60).gmtime.strftime( '%Y%m%d' ) != date.dup.gmtime.strftime( '%Y%m%d' ) then
-				@date = date
-				@io.transaction( @date ) do |diaries|
+				@io.transaction( date ) do |diaries|
 					@diaries = diaries
 					dirty = DIRTY_NONE
-					@diary = self[@date]
+					@diary = self[date]
 					if @diary and @cgi.referer then
 						@diary.add_referer( @cgi.referer )
 						dirty = DIRTY_REFERER
@@ -1726,8 +1809,7 @@ EOS
 					dirty
 				end
 			else
-				@date = date
-				@diary = self[@date]
+				@diary = self[date]
 			end
 		end
 
@@ -1787,11 +1869,25 @@ EOS
 		end
 	end
 
+	#
+	# class TDiaryMonthBase
+	#  base of TDiaryMonth and TDiaryNYear
+	#
+	class TDiaryMonthBase < TDiaryView
+		def eval_rhtml( prefix = '' )
+			if @diaries.empty? and @conf.bot?
+				raise NotFound
+			else
+				super(prefix)
+			end
+		end
+	end
+
 	#
 	# class TDiaryMonth
 	#  show month mode view
 	#
-	class TDiaryMonth < TDiaryView
+	class TDiaryMonth < TDiaryMonthBase
 		def initialize( cgi, rhtml, conf )
 			super
 
@@ -1822,7 +1918,7 @@ EOS
 	# class TDiaryNYear
 	#  show nyear mode view
 	#
-	class TDiaryNYear < TDiaryView
+	class TDiaryNYear < TDiaryMonthBase
 		def initialize(cgi, rhtml, conf)
 			super
 
@@ -1849,6 +1945,12 @@ EOS
 		end
 	end
 
+	#
+	# class TDiaryMonthWithoutFilter
+	#
+	class TDiaryMonthWithoutFilter < TDiaryMonth
+		def referer_filter(referer); end
+	end
 
 	#
 	# class TDiaryLatest
@@ -2018,6 +2120,18 @@ EOS
 		end
 	end
 
+	#
+	# class TDiarySearch
+	#  base of search view mode classes
+	#
+	class TDiarySearch < TDiaryBase
+		attr_reader :last_modified
+		def initialize(cgi, rhtml, conf)
+			super
+			@last_modified = Time.now
+		end
+	end
+
 	#
 	# exception class for TrackBack
 	#
@@ -2077,7 +2191,7 @@ HERE
 			if @cgi.content_type =~ /charset=([^\s;]*)/i then
 				charset = $1
 			end
-			
+
 			url = @cgi.params['url'][0]
 			blog_name = @conf.to_native( @cgi.params['blog_name'][0] || '', charset )
 			title = @conf.to_native( @cgi.params['title'][0] || '', charset )
@@ -2135,4 +2249,10 @@ HERE
 	end
 end
 
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
 # vim: ts=3
