@@ -1,12 +1,13 @@
+# -*- coding: utf-8; -*-
 #
-# defaultio.rb: tDiary IO class for tDiary 2.x format. $Revision: 1.43 $
+# defaultio.rb: tDiary IO class for tDiary 2.x format. $Revision: 1.44 $
 #
-# Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+# Copyright (C) 2001-2005, TADA Tadashi <t@tdtds.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
 module TDiary
 	TDIARY_MAGIC_MAJOR = 'TDIARY2'
-	TDIARY_MAGIC_MINOR = '00.00'
+	TDIARY_MAGIC_MINOR = '01.00'
 	TDIARY_MAGIC = "#{TDIARY_MAGIC_MAJOR}.#{TDIARY_MAGIC_MINOR}"
 
 	def TDiary::parse_tdiary( data )
@@ -33,10 +34,19 @@ module TDiary
 		end
 
 		def restore_comment( file, diaries )
+			minor = ''
 			begin
-				File::open( file, 'r' ) do |fh|
+				File::open( file ) do |fh|
 					fh.flock( File::LOCK_SH )
-					fh.read.split( /\r?\n\.\r?\n/ ).each do |l|
+
+					major, minor = fh.gets.chomp.split( /\./, 2 )
+					unless TDIARY_MAGIC_MAJOR == major then
+						raise StandardError, 'bad file format.'
+					end
+
+					s = fh.read
+					s = migrate_to_01( s ) if minor == '00.00' and !@tdiary.conf['stop_migrate_01']
+					s.split( /\r?\n\.\r?\n/ ).each do |l|
 						headers, body = TDiary::parse_tdiary( l )
 						next unless body
 						comment = Comment::new(
@@ -50,6 +60,7 @@ module TDiary
 				end
 			rescue Errno::ENOENT
 			end
+			return minor == '00.00' ? TDiaryBase::DIRTY_COMMENT : TDiaryBase::DIRTY_NONE
 		end
 
 		def store_comment( file, diaries )
@@ -81,7 +92,7 @@ module TDiary
 
 		def restore_referer( file, diaries )
 			begin
-				File::open( file, 'r' ) do |fh|
+				File::open( file ) do |fh|
 					fh.flock( File::LOCK_SH )
 					fh.read.split( /\r?\n\.\r?\n/ ).each do |l|
 						headers, body = TDiary::parse_tdiary( l )
@@ -113,6 +124,7 @@ module TDiary
 				File::rename( file, file.sub( /\.tdr$/, '.tdr~' ) )
 			rescue Errno::ENOENT
 			end
+			return TDiaryBase::DIRTY_NONE
 		end
 
 		def store_referer( file, diaries )
@@ -149,17 +161,18 @@ module TDiary
 				fh.flock( File::LOCK_EX )
 
 				cache = @tdiary.restore_parser_cache( date, 'defaultio' )
+				force_save = TDiaryBase::DIRTY_NONE
 				unless cache then
-					restore( fh, diaries )
-					restore_comment( cfile, diaries )
-					restore_referer( rfile, diaries )
+					force_save |= restore( fh, diaries )
+					force_save |= restore_comment( cfile, diaries )
+					force_save |= restore_referer( rfile, diaries )
 				else
 					diaries.update( cache )
 				end
 				dirty = yield( diaries ) if iterator?
-				store( fh, diaries ) if dirty & TDiaryBase::DIRTY_DIARY != 0
-				store_comment( cfile, diaries ) if dirty & TDiaryBase::DIRTY_COMMENT != 0
-				store_referer( rfile, diaries ) if dirty & TDiaryBase::DIRTY_REFERER != 0
+				store( fh, diaries ) if ((dirty | force_save) & TDiaryBase::DIRTY_DIARY) != 0
+				store_comment( cfile, diaries ) if ((dirty | force_save) & TDiaryBase::DIRTY_COMMENT) != 0
+				store_referer( rfile, diaries ) if ((dirty | force_save) & TDiaryBase::DIRTY_REFERER) != 0
 				if dirty != TDiaryBase::DIRTY_NONE or not cache then
 					@tdiary.store_parser_cache( date, 'defaultio', diaries )
 				end
@@ -208,19 +221,23 @@ module TDiary
 
 	private
 		def restore( fh, diaries )
+			
 			begin
 				fh.seek( 0 )
 				begin
-					major, minor = fh.gets.split( /\./, 2 )
+					major, minor = fh.gets.chomp.split( /\./, 2 )
 					unless TDIARY_MAGIC_MAJOR == major then
 						raise StandardError, 'bad file format.'
 					end
 
 					# read and parse diary
-					fh.read.split( /\r?\n\.\r?\n/ ).each do |l|
+					style_name = ''
+					s = fh.read
+					s = migrate_to_01( s ) if minor == '00.00' and !@tdiary.conf['stop_migrate_01']
+					s.split( /\r?\n\.\r?\n/ ).each do |l|
 						headers, body = TDiary::parse_tdiary( l )
 						style_name = headers['Format'] || 'tDiary'
-						diary = eval( "#{style( style_name )}::new( headers['Date'], headers['Title'], body, Time::at( headers['Last-Modified'].to_i ) )" )
+						diary = style( style_name )::new( headers['Date'], headers['Title'], body, Time::at( headers['Last-Modified'].to_i ) )
 						diary.show( headers['Visible'] == 'true' ? true : false )
 						diaries[headers['Date']] = diary
 					end
@@ -229,13 +246,14 @@ module TDiary
 					# no magic number when it is new file.
 				end
 			end
+			return minor == '00.00' ? TDiaryBase::DIRTY_DIARY : TDiaryBase::DIRTY_NONE
 		end
 
 		def store( fh, diaries )
 			begin
 				fh.seek( 0 )
 				fh.puts( TDIARY_MAGIC )
-				diaries.each do |date,diary|
+				diaries.sort_by {|date, diary| date}.each do |date,diary|
 					# save diaries
 					fh.puts( "Date: #{date}" )
 					fh.puts( "Title: #{diary.title}" )
@@ -249,5 +267,16 @@ module TDiary
 				fh.truncate( fh.tell )
 			end
 		end
+
+		def migrate_to_01( day )
+			@tdiary.conf.migrate_to_utf8( day )
+		end
 	end
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
