@@ -1,7 +1,8 @@
+# -*- coding: utf-8; -*-
 #
 # default.rb: included TDiary::Filter::DefaultFilter class
 #
-# Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+# Copyright (C) 2001-2005, TADA Tadashi <t@tdtds.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
 
@@ -27,14 +28,14 @@ module TDiary
 			def referer_filter( referer )
 				if not referer then
 					false
-				elsif /[\x00-\x20\x7f-\xff]/ =~ referer then
-					false
+				#elsif /[\x00-\x20\x7f-\xff]/ =~ referer then
+				#	false
 				elsif @conf.bot?
 					false
 				elsif %r|^https?://|i =~ referer
-					ref = CGI::unescape( referer.sub( /#.*$/, '' ).sub( /\?\d{8}$/, '' ) )
+					ref = CGI::unescape( referer.sub( /#.*$/, '' ).sub( /\?\d{8}$/, '' ) ).force_encoding('ASCII-8BIT')
 					@conf.no_referer.each do |noref|
-						return false if /#{noref}/i =~ ref
+						return false if /#{noref.dup.force_encoding('ASCII-8BIT')}/i =~ ref
 					end
 					true
 				else
@@ -44,3 +45,10 @@ module TDiary
 		end
 	end
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
