@@ -1,15 +1,11 @@
+# -*- coding: utf-8; -*-
 #
-# tDiary language setup: English(en) $Revision: 1.4 $
+# tDiary language setup: English(en) $Revision: 1.5 $
 #
-# Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+# Copyright (C) 2001-2005, TADA Tadashi <t@tdtds.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
 
-#
-# setting ruby charctor encoding.
-# 
-$KCODE = 'n'
-
 #
 # 'html_lang' method returns String of HTML language attribute.
 # 
@@ -21,13 +17,18 @@ end
 # 'encoding' method returns String of HTTP or HTML charactor encoding.
 # 
 def encoding
-	'ISO-8859-1'
+	'UTF-8'
 end
 
+def encoding_old
+	'UTF-8'
+end
+
+
 #
 # 'mobile_encoding' method returns charactor encoding in mobile mode.
 def mobile_encoding
-	'ISO-8859-1'
+	'UTF-8'
 end
 
 #
@@ -37,6 +38,13 @@ def to_native( str, charset = nil )
 	str.dup
 end
 
+#
+# 'migrate_to_utf8' method converts string to UTF-8, but dummy in en.
+#
+def migrate_to_utf8( str )
+	str.dup
+end
+
 #
 # 'to_mobile' method converts string automatically to mobile mode encoding.
 # 
@@ -69,3 +77,10 @@ end
 def comment_length
 	120
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
